*! version 1.0.4  21mar2006  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.2  19jun2009  by Marc Muendler  muendler@ucsd.edu

* Country group resetting
capture program drop countrygrp_bem
program define countrygrp_bem
  * Apply BEM cntrybemgrp definitions
  /*-----------------------
   WEU: EMU (3), OWE (6);
   OIN: OIN (5);
   CEE: CEE (2); 
   DEV: APC (1), ODV (4) and RCA (7)
   --------------------------------------------*/
  tab cntrygrp_bem
  gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
  replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
  replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
  replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
  label var cntrybemgrp "Country group BEM"
  rename cntrybemgrp _cntrybemgrp
  encode _cntrybemgrp, gen(cntrybemgrp) label(cntrybem)
  drop _cntrybemgrp
end


/* External data preperation  */
/*----------------------------*/

* Country to BEM group mapping
tempfile cntrgrpbem
use $root/conc/cntry2bemgrp, clear
rename bubakey country
sort country
compress
save `cntrgrpbem'

* Foreign employment and turnover information
use "$addlfile", clear
keep firmid year country turnover_ppp employmt fixdasst_ppp
keep if year==${selyear}
rename turnover_ppp turnover
rename fixdasst_ppp fixdasst
sort country 
merge country using `cntrgrpbem' 
tab _merge
keep if _merge==3
drop _merge
countrygrp_bem
collapse (sum) turnover employmt fixdasst, by(firmid year cntrybemgrp) fast
decode cntrybemgrp, generate(_cntrybemgrp)
replace _cntrybemgrp = substr(_cntrybemgrp,1,2)
drop cntrybemgrp
reshape wide turnover employmt fixdasst, i(firmid year) j(_cntrybemgrp) string
reshape wide turnover?? employmt?? fixdasst??, i(firmid) j(year)
foreach reg in $regagg {
  local r2dg = substr("`reg'",1,2)
  foreach var in turnover employmt fixdasst {
    foreach year in ${selyear} {
      local yr = substr("`year'",3,2)
      * if "`var'"=="employmt"  replace `var'`r2dg'`year' = log(`var'`r2dg'`year')
      * else                    replace `var'`r2dg'`year' = log(`var'`r2dg'`year')
      * rename `var'`r2dg'`year' ln_`var'`r2dg'`yr'
      rename `var'`r2dg'`year' `var'`r2dg'`yr'
      * replace ln_`var'`r2dg'`yr'=0 if ln_`var'`r2dg'`yr'==.   // presence interaction b/c presence indicators in selection eq.
      replace `var'`r2dg'`yr'=0 if `var'`r2dg'`yr'==.  // absent MNEs have zero factor use
      * recast float ln_`var'`r2dg'`yr', force
      recast float `var'`r2dg'`yr', force
      * if "`var'"=="turnover"  label var ln_`var'`r2dg'`yr' "ln Turnover host [thsd] `yr'"
      * if "`var'"=="employmt"  label var ln_`var'`r2dg'`yr' "ln Employment host `yr'"
      * if "`var'"=="fixdasst"  label var ln_`var'`r2dg'`yr' "ln Fixed assets host [thsd] `yr'"
      if "`var'"=="turnover"  label var `var'`r2dg'`yr' "Turnover host [thsd] `yr'"
      if "`var'"=="employmt"  label var `var'`r2dg'`yr' "Employment host `yr'"
      if "`var'"=="fixdasst"  label var `var'`r2dg'`yr' "Fixed assets host [thsd] `yr'"
      }
    }
  }
sort firmid
compress
save ${addlaffl}

* German Laender information
use "$root/Xmatch/affils-fdiall-ustan-96-01-eur-03mar2006", clear
keep firmid year state_par indwest_par
foreach var in state_par indwest_par {
  local lbl`var' : variable label `var'
  rename `var' `var'_
  }
keep if year==${selyear} | year==${tlogyear}
bysort firmid year: keep if _n==1
reshape wide state_par indwest_par, i(firmid) j(year)
foreach year in $selyear $tlogyear {
  foreach var in state_par indwest_par {
    label var `var'_`year' "`lbl`var'' `year'"
    }
  }
sort firmid
compress
save ${addlfirm}

* Unionization
tempfile union
use "$root/wages/union_sec_bem", clear
sort sec_bem year
by sec_bem: replace union = union[_n-1] if union==0 /* update years with missing information (${selyear}, ${tlogyear} are missing) with preceding information */
keep if year==${selyear} | year==${tlogyear}
local lbl : variable label union
rename union union_
reshape wide union, i(sec_bem) j(year)
foreach year in $selyear $tlogyear {
  label var union_`year' "Unionization `year'"
  }
rename sec_bem sec1_bem
sort sec1_bem
compress
save `union'

* Outside margin
use $root/trade/ger-impinp-exp-secbem-ctrygrp-2000, clear
rename buba country
sort nace11_code country
* aggregate sectors and regions
sort nace11_code
merge nace11_code using $root/conc/nace2bem
tab _m
keep if _m==3
drop _m
sort country
merge country using `cntrgrpbem'
tab _m
keep if _m==3
drop _m
countrygrp_bem
collapse (sum) import export impinp, by(nace11_code sec_bem cntrybemgrp) fast
rename sec_bem sec1_bem
rename import imp
rename export exp
label var sec1_bem "Sector codes (BEM)"
label var imp "Import (in Thd EUR)"
label var exp "Export (in Thd EUR)"
label var impinp "Imp. inputs (in Thd EUR)"
order sec1_bem cntrybemgrp
sort sec1_bem cntrybemgrp
foreach var in imp exp impinp {
  local lbl`var' : variable label `var'
  local lbl`var' = subinstr("`lbl`var''"," (in Thd EUR)","",.)
  replace `var' = ln(`var')
  }
reshape wide imp exp impinp, i(nace11_code sec1_bem) j(cntrybemgrp)
local x=0
foreach name in $regagg {
  local x=`x'+1
  foreach var in imp exp impinp {
    rename `var'`x' `var'_`name'_${tlogyear}
    label var `var'_`name'_${tlogyear} "ln `lbl`var'' `name' 2000"
    }
  }

sort sec1_bem
merge sec1_bem using `union'
tab _m
drop _m
sort sec1_bem
compress

rename nace11_code nace1
preserve
  keep nace1 *_${selyear}
  sort nace1
  save ${addlsec_${selyear}}
restore, preserve
  keep nace1 *_${tlogyear}
  sort nace1
  save ${addlsec_${tlogyear}}
restore
