*! version 1.0.2  30jan2006  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.2  20jun2009  by Marc Muendler  muendler@ucsd.edu

clear
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/make-regdata-cf-allyrs-pt$par-af$aff.log", replace

capture program drop lblneutr
program define lblneutr
  syntax [varlist]
  foreach var of varlist `varlist' {
    local lbl : variable label `var'
    forvalues year = 1996/2001 {
      local lbl = trim(subinstr("`lbl'","`year'","",.))
      }
    foreach yr in 96 97 98 99 00 01 {
      local lbl = trim(subinstr("`lbl'","`yr'","",.))
      }
    label variable `var' "`lbl'"
    }
end

adopath + "$root/%stata/ado"

#delimit ;

/* prepare wage/employee at parent */
/*---------------------------------*/

tempfile rwag;
use firmid year avrg_wage_par using "$root/Xustan/ustan-fdi-match-wages-defl-15jun2009.dta";
duplicates drop;
gen lnw_HO = log(avrg_wage_par);
label var lnw_HO "Log Average HOM wage/employee";
keep if lnw_HO ~= .;
keep firmid year lnw_HO;
rename firmid mneid;
sort mneid year;
save `rwag';

/* data */
/*------*/

foreach tlogyear in 1998 1999 2000 2001 {;

tempfile mnes`tlogyear';
local tlogyr = substr("`tlogyear'",3,2);
local selyear = `tlogyear' - ${yrdiff};
local selyr = substr("`selyear'",3,2);

*----------------------following code identical to translog-selct-2stp-cf.do----------------------------------------------------;
*-----deactivate: `usemissg' ---------------------------------------------------------------------------------------------------;
*-----substitute: `tlogyear' for 2000, `tlogyr' for 00, ${yrdiff} for 4, `selyear' for 1996, `selyr' for 96, $dpref/ for $dp/---;
*-----substitute: /v6fs for /v6, chosen_`reg'_now for chosen_`reg'_`year' ------------------------------------------------------;
*-----substitute: Xdata/pop-reg-nonattrition-pt$par-af$aff-allyrs for Xdata/pop-reg-nonattrition-pt$par-af$aff -----------------;
*-----substitute: Xdata/mvprobit-outwfdi-ustan-`tlogyear'd$yrdiff... for Xdata/mvprobit-outwfdi-ustan-`tlogyear'... ------------;

tempfile popinfo;
use "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff-allyrs", clear;
keep if year==`tlogyear';
keep mneid i*;  /* do not update sample-specific nofdi indicators for translog */
sort mneid;
compress;
save `popinfo';

if "$par" == "manf" | "$par" == "" {;
  };
if "$par" == "all" {;
  local howmany = "0 1";
  };

local usemissg 1;
* foreach usemissg in `howmany' {; /* begin `usemissg' loop */

use "$rootslct/Xdata/mneid-outwfdi-ustan-`tlogyear'-translog-$waglvl-pt$par-af$aff", clear;
drop naff l;

replace cntrybemgrp=(substr(cntrybemgrp,1,2));
foreach var in s w t k {;
  foreach reg in HOM $regagg {;
    local r2dg = substr("`reg'",1,2);
    qui gen double cf`r2dg'_`var' = cf`r2dg' * `var';
    };
  };
foreach reg in HOM $regagg {;
  local r2dg = substr("`reg'",1,2);
  qui gen y`r2dg' = cf`r2dg'_s;
  };

if `usemissg' == 0 {;
* keep usemissg observations as they are;
    drop nofdi;
    /* s:costShare y:Labor w:Wage t:Turnover("Output") k:Capital */
    reshape wide s w t k y?? cf??_w cf??_t cf??_k cf??_s cf??, i(mneid) j(cntrybemgrp) string;
    };

if `usemissg' == 1 {;
* construct stacked system;
    foreach var of varlist s w t k y?? cf??_w cf??_t cf??_k cf??_s cf?? {;
        replace `var'=0 if `var'==.;
       };
    reshape wide s w t k y?? cf??_w cf??_t cf??_k cf??_s cf?? nofdi, i(mneid) j(cntrybemgrp) string;
    };

foreach reg in HOM $regagg {;
  local r2dg = substr("`reg'",1,2);
  rename y`r2dg'`r2dg' y`r2dg';
  rename cf`r2dg'`r2dg' cf`r2dg';
  drop y`r2dg'?? cf`r2dg'??;
  };
order mneid y??;

local waglvl "$waglvl";
if "`waglvl'"=="frmswewage"  local waglvl "frmowwwage";
sort mneid;
merge mneid using "$rootslct/Xdata/mvprobit-outwfdi-ustan-`tlogyear'd$yrdiff-`waglvl'-pt$par-af$aff";
tab _merge;
drop _merge;
sort mneid;

* competitor regressors;
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-`selyear'-costothr-$waglvl-pt$par-af$aff";
tab _merge;
foreach var in s k t l w wb {;
  foreach reg in $regagg {;
    qui gen _avg_`var'_`reg' = `var'_othr_`reg' if _m==2; /* market average (mneid==0 in using data) */
    qui egen _rpl_`var'_`reg' = max(_avg_`var'_`reg');
    qui replace `var'_othr_`reg' = _rpl_`var'_`reg' if `var'_othr_`reg'==.; /* replace missing competitor info with market average (mneid==0 in using data) */
    drop _avg_`var'_`reg' _rpl_`var'_`reg';
    };
  };
drop if mneid==0;
drop _merge;
sort mneid;
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-`selyear'-wwlocvars-pt$par-af$aff";
* following code only used when "ustan-`selyear'-locvars" loaded (not "-wwlocvars")
* foreach reg in $regagg {;
*   local r2dg = substr("`reg'",1,2);
*   foreach var in employmt ln_dist ln_gdp ln_gdp_cap ln_consum_exp ln_cons_cap lh99_1 lh99_2 {; 
*     qui gen _avg_`var' = `var'_othr_`reg' if _m==2; /* market average (mneid==0 in using data) */
*     qui egen _rpl_`var' = max(_avg_`var');
*     qui replace `var'_othr_`reg' = _rpl_`var' if `var'_othr_`reg'==.;  /* replace missing competitor info with market average (mneid==0 in using data) */
*     rename `var'_othr_`reg' `var'_othr_`r2dg'; 
*     drop _avg_`var' _rpl_`var';
*     };
*   };
drop if mneid==0;
tab _merge;
drop _merge;
sort mneid;

*----------------------above code identical to prep-mvprobit-med-wagediff.do---------------------------------------------;

* parent level regressors;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  drop chosen_`reg'_now chosen_`reg'_${yrdiff}yrlg;  /* drop sample presence indicators, use population indicators below */
  };
drop w_HOM_now w_othr_HOM ln_wagediff*; rename w_HOM_${yrdiff}yrlg w_HOM;
replace w_HOM = exp(w_HOM);  /* plain wage */
local lbl : variable label w_HOM;
local lbl = subinstr("`lbl'","ln ","",.);
label var w_HOM "`lbl'";

* wage variable redefinitions: all wages for location selection in 1,000 EUR;
replace w_HOM = w_HOM/1000;
local lbl : variable label w_HOM;
local lbl = "`lbl' [Thd EUR]";
label var w_HOM "`lbl'";
foreach reg in $regagg {;
  replace w_othr_`reg' = w_othr_`reg'/1000;
  local lbl : variable label w_othr_`reg';
  local lbl = "`lbl' [Thd EUR]";
  label var w_othr_`reg' "`lbl'";
  };

* wage variable redefinitions: all wages for location selection not in logs (plain);
* replace w_HOM = log(w_HOM);
* local lbl : variable label w_HOM;
* local lbl = "ln `lbl'";
* label var w_HOM "`lbl'";
* foreach reg in $regagg {;
*   replace w_othr_`reg' = log(w_othr_`reg');
*   local lbl : variable label w_othr_`reg';
*   local lbl = "ln `lbl'";
*   label var w_othr_`reg' "`lbl'";
*   };

* regional presence indicators and affiliate counts from population information;
gen byte iHOnow = 1;  /* Permanent presence in Home */
label var iHOnow "Presence HOM  current year";
sort mneid;
merge mneid using `popinfo', nokeep;
tab _m;
drop _m;

lblneutr *;
sort mneid;
gen year = `tlogyear';
label var year "Year (production, selection: -$yrdiff)";

save `mnes`tlogyear'';

};  /* close `tlogyear' loop */

use `mnes1998';
forvalues tlogyear = 1999/2001 {;
  append using `mnes`tlogyear'';
  };

foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  gen double i`r2dg'${yrdiff}yrlg_wHO = i`r2dg'${yrdiff}yrlg * w_HOM;
  gen double i`r2dg'${yrdiff}yrlg_w`r2dg' = i`r2dg'${yrdiff}yrlg * w_othr_`r2dg';
  label var i`r2dg'${yrdiff}yrlg_wHO     "Past Pres. `r2dg' X wage HO";
  label var i`r2dg'${yrdiff}yrlg_w`r2dg' "Past Pres. `r2dg' X wage `r2dg'";
  };

* parent wage;
sort mneid year;
qui count;
local chkn = `r(N)';
merge mneid year using `rwag', nokeep;
qui count;
if `r(N)'~=`chkn'  STOP;
tab _merge;
drop _merge;

* affiliate wages;
sort sec1_bem;
merge sec1_bem using "tex/desc/wagediffs/swediffs-$waglvl-1998-cntrygrp.dta", nokeep;
tab _m;
drop _m;

* impute affiliate wages from current MNE wage premia by sector (Swedish MNEs);
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  gen double lnw_`r2dg' = w`r2dg' + wdif`reg';  /* wdif`reg' is log wage premium */
  label var lnw_`r2dg' "Log imputed `reg' wage";
  drop wdif`reg';
  };

compress;
sort mneid year;
drop cf??_s?? cfHO_* state_par_${yrdiff}yrlg state_par_now;
local wag = substr("$waglvl",4,3);
* order mneid year nreg sec1_bem iHOnow iHO${yrdiff}yrlg iCE${yrdiff}yrlg iCEnow iDE${yrdiff}yrlg iDEnow iOI${yrdiff}yrlg iOInow iWE${yrdiff}yrlg iWEnow w_HOM iCE${yrdiff}yrlg_wHO iCE${yrdiff}yrlg_wCE iDE${yrdiff}yrlg_wHO iDE${yrdiff}yrlg_wDE iOI${yrdiff}yrlg_wHO iOI${yrdiff}yrlg_wOI iWE${yrdiff}yrlg_wHO iWE${yrdiff}yrlg_wWE yHO yCE yDE yOI yWE sHO kHO tHO wHO cfHO sCE kCE tCE wCE cfCE sDE kDE tDE wDE cfDE sOI kOI tOI wOI cfOI sWE kWE tWE wWE cfWE cfCE_wHO cfCE_wCE cfCE_wDE cfCE_wOI cfCE_wWE cfCE_tHO cfCE_tCE cfCE_tDE cfCE_tOI cfCE_tWE cfCE_kHO cfCE_kCE cfCE_kDE cfCE_kOI cfCE_kWE cfDE_wHO cfDE_wCE cfDE_wDE cfDE_wOI cfDE_wWE cfDE_tHO cfDE_tCE cfDE_tDE cfDE_tOI cfDE_tWE cfDE_kHO cfDE_kCE cfDE_kDE cfDE_kOI cfDE_kWE cfOI_wHO cfOI_wCE cfOI_wDE cfOI_wOI cfOI_wWE cfOI_tHO cfOI_tCE cfOI_tDE cfOI_tOI cfOI_tWE cfOI_kHO cfOI_kCE cfOI_kDE cfOI_kOI cfOI_kWE cfWE_wHO cfWE_wCE cfWE_wDE cfWE_wOI cfWE_wWE cfWE_tHO cfWE_tCE cfWE_tDE cfWE_tOI cfWE_tWE cfWE_kHO cfWE_kCE cfWE_kDE cfWE_kOI cfWE_kWE nofdiHO nofdiCE nofdiDE nofdiOI nofdiWE `wag'diff_CEE ln_`wag'diff_CEE `wag'diff_DEV ln_`wag'diff_DEV `wag'diff_OIN ln_`wag'diff_OIN `wag'diff_WEU ln_`wag'diff_WEU ln_inter_${yrdiff}yrlg ln_inter_now indwest_par_${yrdiff}yrlg indwest_par_now union_${yrdiff}yrlg union_now ln_employmt_par_${yrdiff}yrlg ln_employmt_par_now ln_fixdasst_par_${yrdiff}yrlg ln_fixdasst_par_now ln_assettot_par_${yrdiff}yrlg ln_assettot_par_now ln_profits_par_${yrdiff}yrlg ln_profits_par_now ln_turnover_par_${yrdiff}yrlg ln_turnover_par_now ln_equity_par_${yrdiff}yrlg ln_equity_par_now ln_liab_par_${yrdiff}yrlg ln_liab_par_now ln_caplabrat_par_${yrdiff}yrlg ln_caplabrat_par_now profeqtyrat_par_${yrdiff}yrlg profeqtyrat_par_now ln_exports_par_${yrdiff}yrlg ln_exports_par_now ln_intmed_par_${yrdiff}yrlg ln_intmed_par_now ln_wb_par_${yrdiff}yrlg ln_wb_par_now ln_turnoverCE${yrdiff}yrlg ln_employmtCE${yrdiff}yrlg ln_fixdasstCE${yrdiff}yrlg ln_turnoverDE${yrdiff}yrlg ln_employmtDE${yrdiff}yrlg ln_fixdasstDE${yrdiff}yrlg ln_turnoverOI${yrdiff}yrlg ln_employmtOI${yrdiff}yrlg ln_fixdasstOI${yrdiff}yrlg ln_turnoverWE${yrdiff}yrlg ln_employmtWE${yrdiff}yrlg ln_fixdasstWE${yrdiff}yrlg imp_CEE_now exp_CEE_now impinp_CEE_now imp_DEV_now exp_DEV_now impinp_DEV_now imp_OIN_now exp_OIN_now impinp_OIN_now imp_WEU_now exp_WEU_now impinp_WEU_now ln_mktacc_othr s_othr_CEE s_othr_DEV s_othr_HOM s_othr_OIN s_othr_WEU k_othr_CEE k_othr_DEV k_othr_HOM k_othr_OIN k_othr_WEU t_othr_CEE t_othr_DEV t_othr_HOM t_othr_OIN t_othr_WEU l_othr_CEE l_othr_DEV l_othr_HOM l_othr_OIN l_othr_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU wb_othr_CEE wb_othr_DEV wb_othr_HOM wb_othr_OIN wb_othr_WEU employmt_othr ln_dist_othr ln_gdp_othr ln_gdp_cap_othr ln_consum_exp_othr ln_cons_cap_othr lh99_1_othr lh99_2_othr;
order mneid year nreg sec1_bem iHOnow iHO${yrdiff}yrlg iCE${yrdiff}yrlg iCEnow iDE${yrdiff}yrlg iDEnow iOI${yrdiff}yrlg iOInow iWE${yrdiff}yrlg iWEnow w_HOM iCE${yrdiff}yrlg_wHO iCE${yrdiff}yrlg_wCE iDE${yrdiff}yrlg_wHO iDE${yrdiff}yrlg_wDE iOI${yrdiff}yrlg_wHO iOI${yrdiff}yrlg_wOI iWE${yrdiff}yrlg_wHO iWE${yrdiff}yrlg_wWE yHO yCE yDE yOI yWE sHO kHO tHO wHO cfHO sCE kCE tCE wCE cfCE sDE kDE tDE wDE cfDE sOI kOI tOI wOI cfOI sWE kWE tWE wWE cfWE cfCE_wHO cfCE_wCE cfCE_wDE cfCE_wOI cfCE_wWE cfCE_tHO cfCE_tCE cfCE_tDE cfCE_tOI cfCE_tWE cfCE_kHO cfCE_kCE cfCE_kDE cfCE_kOI cfCE_kWE cfDE_wHO cfDE_wCE cfDE_wDE cfDE_wOI cfDE_wWE cfDE_tHO cfDE_tCE cfDE_tDE cfDE_tOI cfDE_tWE cfDE_kHO cfDE_kCE cfDE_kDE cfDE_kOI cfDE_kWE cfOI_wHO cfOI_wCE cfOI_wDE cfOI_wOI cfOI_wWE cfOI_tHO cfOI_tCE cfOI_tDE cfOI_tOI cfOI_tWE cfOI_kHO cfOI_kCE cfOI_kDE cfOI_kOI cfOI_kWE cfWE_wHO cfWE_wCE cfWE_wDE cfWE_wOI cfWE_wWE cfWE_tHO cfWE_tCE cfWE_tDE cfWE_tOI cfWE_tWE cfWE_kHO cfWE_kCE cfWE_kDE cfWE_kOI cfWE_kWE nofdiHO nofdiCE nofdiDE nofdiOI nofdiWE `wag'diff_CEE ln_`wag'diff_CEE `wag'diff_DEV ln_`wag'diff_DEV `wag'diff_OIN ln_`wag'diff_OIN `wag'diff_WEU ln_`wag'diff_WEU ln_inter_${yrdiff}yrlg ln_inter_now indwest_par_${yrdiff}yrlg indwest_par_now union_${yrdiff}yrlg union_now employmt_par_${yrdiff}yrlg employmt_par_now fixdasst_par_${yrdiff}yrlg fixdasst_par_now assettot_par_${yrdiff}yrlg assettot_par_now profits_par_${yrdiff}yrlg profits_par_now turnover_par_${yrdiff}yrlg turnover_par_now equity_par_${yrdiff}yrlg equity_par_now liab_par_${yrdiff}yrlg liab_par_now caplabrat_par_${yrdiff}yrlg caplabrat_par_now profeqtyrat_par_${yrdiff}yrlg profeqtyrat_par_now exports_par_${yrdiff}yrlg exports_par_now intmed_par_${yrdiff}yrlg intmed_par_now wb_par_${yrdiff}yrlg wb_par_now turnoverCE${yrdiff}yrlg employmtCE${yrdiff}yrlg fixdasstCE${yrdiff}yrlg turnoverDE${yrdiff}yrlg employmtDE${yrdiff}yrlg fixdasstDE${yrdiff}yrlg turnoverOI${yrdiff}yrlg employmtOI${yrdiff}yrlg fixdasstOI${yrdiff}yrlg turnoverWE${yrdiff}yrlg employmtWE${yrdiff}yrlg fixdasstWE${yrdiff}yrlg imp_CEE_now exp_CEE_now impinp_CEE_now imp_DEV_now exp_DEV_now impinp_DEV_now imp_OIN_now exp_OIN_now impinp_OIN_now imp_WEU_now exp_WEU_now impinp_WEU_now ln_mktacc_othr s_othr_CEE s_othr_DEV s_othr_HOM s_othr_OIN s_othr_WEU k_othr_CEE k_othr_DEV k_othr_HOM k_othr_OIN k_othr_WEU t_othr_CEE t_othr_DEV t_othr_HOM t_othr_OIN t_othr_WEU l_othr_CEE l_othr_DEV l_othr_HOM l_othr_OIN l_othr_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU wb_othr_CEE wb_othr_DEV wb_othr_HOM wb_othr_OIN wb_othr_WEU employmt_othr ln_dist_othr ln_gdp_othr ln_gdp_cap_othr ln_consum_exp_othr ln_cons_cap_othr lh99_1_othr lh99_2_othr;
save "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf", replace;

log close;
cd "$root";
