*! version 1.0.5  15jan2006  by Marc Muendler  muendler@ucsd.edu

clear
set memory 500m
set more off
capture log close

cd "$rootslct"
log using "logs/prep-costs-others-$waglvl-pt$par-af$aff-allyrs.log", replace

/* Calculate Competitor Wages, Turnover, Capital Stock, Employment */
/*-----------------------------------------------------------------*/

foreach year in 1997 1998 1999 {  /* only difference to prep-costs-other.do */

*----------------------following code identical to prep-costs-others.do---------------------------------------------------------

use "Xdata/mneid-outwfdi-ustan-`year'-translog-$waglvl-pt$par-af$aff", clear

* reshape
keep mneid sec1_bem cntrybemgrp s k t w l
gen double cap = exp(k)
label var cap "exp(k)"
gen double outp = exp(t)
label var outp "exp(t)"
gen double empl = exp(l)
label var empl "exp(l)"
gen double wage = exp(w)
label var wage "exp(w)"
gen double wb = wage*empl
label var wb "wage*empl"
drop k t l w
foreach var in s cap outp empl wb wage {
  rename `var' `var'_othr_
  }
reshape wide s_ cap_ outp_ empl_ wb_ wage_, i(mneid) j(cntrybemgrp) string

* firm-by-firm averages over all other MNEs
count
local totnum = `r(N)'
gen _no = _n
order _n
compress
preserve
forvalues i = 0/`totnum' {
  tempfile nonw`i' w`i'
  restore, preserve
  * mean competitor wage by region and sector
  local sec1bem = sec1_bem[`i']
  qui drop if _no == `i'
  if `sec1bem'~=. { 
    qui keep if sec1_bem == `sec1bem'
    }
  collapse (sum) wb_* empl_* , fast
  foreach reg in $reghomagg {
    qui gen double w_othr_`reg' = wb_othr_`reg' / empl_othr_`reg'
    }
* alternative:
* collapse (mean) wage_* (sum) empl_* wb_* , fast
  gen _no = `i'
  order _no
  qui compress
  qui save `w`i''
  restore, preserve
  * mean non-wage variables by region
  qui drop if _no == `i'
  collapse (mean) s_* (sum) cap_* outp_* empl_* , fast
  foreach reg in $reghomagg {
    gen double k_othr_`reg' = log(cap_othr_`reg')
    gen double t_othr_`reg' = log(outp_othr_`reg')
    gen double l_othr_`reg' = log(empl_othr_`reg')
    }
  drop cap_* outp_* empl_*
  gen _no = `i'
  order _no
  qui compress
  qui save `nonw`i''
  }
restore, preserve

tempfile wages
qui use `w0', clear
forvalues i = 1/`totnum' {
  qui append using `w`i''
  }
sort _no
save `wages'
restore, preserve

tempfile nonwages
qui use `nonw0', clear
forvalues i = 1/`totnum' {
  qui append using `nonw`i''
  }
sort _no
save `nonwages'


/* Finalize */
/*----------*/

restore
keep _no mneid
sort _no
merge _no using `wages'
tab _m
count if _m==1
if `r(N)' {
  disp as err "Incomplete observations for competitor wages"
  STOP
  }
drop _m

sort _no
merge _no using `nonwages'
tab _m
count if _m==1
if `r(N)' {
  disp as err "Incomplete observations for competitor nonwage variables"
  STOP
  }

drop _m _no empl_*

foreach reg in $reghomagg {
  label var s_othr_`reg'  "Cost share (theta) `reg'"
  label var k_othr_`reg'  "ln Fixed asset stock `reg'"
  label var t_othr_`reg'  "ln Turnover `reg'"
  label var l_othr_`reg'  "ln Employment `reg'"
  label var w_othr_`reg'  "Wage rate `reg'"
  label var wb_othr_`reg' "Wage bill `reg'"
  }

replace mneid = 0 if mneid==.
order mneid s_* k_* t_* l_* w_* wb_*
compress
sort mneid
save "Xdata/mneid-outwfdi-ustan-`year'-costothr-$waglvl-pt$par-af$aff", replace
}

*----------------------above code identical to prep-costs-others.do---------------------------------------------------------

log close
cd "$root"
