*! version 1.0.2  19nov2008  by Marc Muendler  muendler@ucsd.edu

version 8.2
clear
set memory 500m
set more off
capture log close

capture mkdir "$rootslct/tex/desc"
capture mkdir "$rootslct/tex/desc/quarts"
capture mkdir "$rootslct/tex/pop"
capture mkdir "$rootslct/tex/pop/pt$par-af$aff"

cd "$rootslct"

log using "logs/prep-$waglvl-pt$par-af$aff-quarts.log", replace

foreach year in 1996 1998 2001 {

/* Wage preparation */

local tlogyear = `year'                    // use 1996: initial sample year for quartile cutoffs
local tlogyr = substr("`tlogyear'",3,2)
local selyear = `tlogyear' - ${yrdiff}
local selyr = substr("`selyear'",3,2)

global tlogyear = `tlogyear'
global selyear  = `selyear'
local wfl = substr("${waglvl}",4,3)
if "`wfl'"=="swe"  local wfl "oww"
global year `year'
* extra years for compatibility with prep-mvprobit-med-wagediff-allyrs.do and %40/prep-translog-fdidata.do
tempfile `wfl'`selyr' `wfl'99 `wfl'`tlogyr' hom`wfl'`selyr' hom`wfl'99 hom`wfl'`tlogyr' homsecwag swe98 homswe98
global `wfl'`selyr' "``wfl'`selyr''"
global `wfl'99 "``wfl'99'"
global `wfl'`tlogyr' "``wfl'`tlogyr''"
global swe98 "`swe98'"
global hom`wfl'`selyr' "`hom`wfl'`selyr''"
global hom`wfl'99 "`hom`wfl'99'"
global hom`wfl'`tlogyr' "`hom`wfl'`tlogyr''"
global homswe98 "`homswe98'"
global homsecwag "`homsecwag'"
do $dpref/#translog-`wfl'wages.do

/* MiDi */

use "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff-allyrs", clear
keep if year==`year'  // use initial sample year for quartile cutoffs

/* Merge external wage data, keep only relevant year */

if substr("$waglvl",4,3)=="oww" | substr("$waglvl",4,3)=="ubs" | substr("$waglvl",4,3)=="uno" {  /* wb_par wb_ppp wage_par wage_ppp mhomwage */
  do $dpref/#translog-yearselect-wages.do
  }
if substr("$waglvl",4,3)=="swe" {  /* wb_par wb_ppp wage_par wage_ppp */
  do $dpref/#translog-avgswe-wages.do
  }
if substr("$waglvl",4,3)=="mne" {  /* wb_par wb_ppp wage_par wage_ppp */
  gen wage_ppp = wb_ppp / employmt
  gen wage_par = wb_par / employmt_par 
  }


/* Cutoff derivation */

egen median_wage_hom = median(wage_par)
egen sum_empl = sum(employmt), by(country)
egen sum_empl_hom = sum(employmt_par)
keep country wage_ppp median_wage_hom sum_empl sum_empl_hom
order country wage_ppp sum_empl median_wage_hom sum_empl_hom
duplicates drop
drop if wage_ppp==.

count
local cutoff = `r(N)'/4
gsort -wage_ppp
gen byte quartile = 1 if _n<`cutoff'
replace quartile = 2 if _n>=`cutoff' & _n<`cutoff'*2
replace quartile = 3 if _n>=`cutoff'*2 & _n<`cutoff'*3
replace quartile = 4 if _n>=`cutoff'*3
local uppwfl = upper(substr("${waglvl}",4,3))
label var quartile "Wage quartile (`uppwfl')"
disp "Year: " in yellow `tlogyear'
list country wage_ppp median_wage_hom sum_empl sum_empl_hom quartile

preserve
  use "$root/wages/unido-wages-defl-1996-2001", clear
  keep if year==`year'
  disp "Year: " in yellow "`tlogyear'" in green "; summ wage_ppp if buba==0"
  summ wage_ppp if buba==0
  use mneid w cntrybemgrp using "$rootslct/Xdata/mneid-outwfdi-ustan-`year'-translog-$waglvl-pt$par-af$aff.dta", clear
  keep if cntrybemgrp == "HOM"
  rename w w_HOM
  replace w_HOM = exp(w_HOM)
  disp "Year: " in yellow "`tlogyear'" in green "; summ w_HOM"
  summ w_HOM
restore, preserve
  tempfile all col2
  qui do "$root/conc/enbubalo05.do"
  label values country enbubalo
  keep country wage_ppp median_wage_hom quartile
  list country wage_ppp median_wage_hom quartile
  tsset country quartile
  qui summ country
  local mincntry = `r(min)'
  tsappend, add(1) panel(`mincntry')
  sort country quartile
  replace country = 0 if country==`mincntry' & quartile==quartile[_n-1]+1
  replace quartile = . if country==0
  qui summ median_wage_hom
  replace wage_ppp = `r(mean)' if country==0
  replace median_wage_hom = `r(mean)' if country==0
  sort country quartile
  disp "Year: " in yellow "`tlogyear'"
  gsort -wage_ppp
  list country wage_ppp if wage_ppp>=median_wage_hom
  sort country
  save "tex/desc/quarts/pt$par-af$aff-$waglvl-`tlogyear'.dta", replace
  decode country, generate(_rowname)
  replace _rowname = trim(substr(_rowname,1,index(_rowname," ("))) if index(_rowname," (")>0
  replace _rowname = "\it Germany" if _rowname=="DM"
  replace _rowname = string(quartile) + ": " + _rowname
  keep _rowname wage_ppp
  order _rowname wage_ppp
  qui count
  local tot = `r(N)'
  gsort -wage_ppp
  save `all'
  use `all'
  keep if _n>int(`tot'/2+.5)
  rename _rowname _rowname2
  rename wage_ppp wage_ppp2
  gsort -wage_ppp2
  save `col2'
  use `all'
  keep if _n<=int(`tot'/2+.5)
  rename _rowname _rowname1
  rename wage_ppp wage_ppp1
  gsort -wage_ppp1
  merge using `col2'
  compress
  drop _m
  save "tex/pop/pt$par-af$aff/countrylist-$waglvl-`tlogyear'.dta", replace
  gen str _wage_ppp1 = string(int(wage_ppp1))
  gen str _wage_ppp2 = string(int(wage_ppp2))
  drop wage_ppp1 wage_ppp2
  rename _wage_ppp1 wage_ppp1
  rename _wage_ppp2 wage_ppp2
  order _rowname1 wage_ppp1 _rowname2 wage_ppp2
  replace wage_ppp1 = substr(wage_ppp1,1,length(wage_ppp1)-3)+","+substr(wage_ppp1,length(wage_ppp1)-2,.) if length(wage_ppp1)>3
  replace wage_ppp2 = substr(wage_ppp2,1,length(wage_ppp2)-3)+","+substr(wage_ppp2,length(wage_ppp2)-2,.) if length(wage_ppp2)>3
  foreach var in _rowname1 wage_ppp1 _rowname2 {
    replace `var' = `var' + " &"
    }
  replace wage_ppp1 = wage_ppp1 + "&"
  replace wage_ppp2 = wage_ppp2 + " \" + "\"
  outsheet using "tex/pop/pt$par-af$aff/countrylist-$waglvl-`tlogyear'.tex", noquote nonames replace
restore, preserve
  keep country quartile
  label define quarts 1 "Q1" 2 "Q2" 3 "Q3" 4 "Q4"
  label values quartile quarts
  sort country
  if `tlogyear'==1996  save "tex/desc/quarts/$waglvl-quartiles", replace  // only for initial year: 1996
restore, preserve
  collapse (mean) wage_ppp (sum) sum_empl, by(quartile)
  disp "Year: " in yellow "`tlogyear'"
  list quartile wage_ppp sum_empl
restore

}

log close
