*! version 1.0.7  14nov2006  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.2  20jun2009  by Marc Muendler  muendler@ucsd.edu

/* Varcov correction assumes that selection equations have constant */
/* Selection equation assumed to have constant as last regressor */
/* Varcov correction assumes that sureg equations do not have constant (add a regressor called ones if constant needed) */
/* Sure equation assumed to have Mills ratio as last regressor */
/* Regional wages are supposed to be first (5) regressors in SUR equations */

clear
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/reg-extmarg-$waglvl-pt$par-af$aff.log", replace

capture mkdir "$rootslct/estmat/v6"
capture mkdir "$rootslct/estmat/v6/pt$par-af$aff-$waglvl"
capture mkdir "$rootslct/estmat/v6/pt$par-af$aff-$waglvl/extmarg"

mat drop _all
local maxvars 3  /* longest possible extensive margin varlist */

adopath + "$root/%stata/ado"

#delimit ;

/* variable sets for extensive margin regressions */
/*------------------------------------------------*/

do $dp/!varsets.do;

/* data */
/*------*/

tempfile popinfo;
use "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff", clear;
keep if year==2000;
keep mneid i* naff*;  /* do not update sample-specifi nofdi indicators for translog */
sort mneid;
compress;
save `popinfo';

use "$rootslct/Xdata/mneid-outwfdi-ustan-2000-translog-$waglvl-pt$par-af$aff", clear;
drop cf*;

replace cntrybemgrp=(substr(cntrybemgrp,1,2));

* construct stacked system;
foreach var in s w t k l naff {;
    replace `var'=0 if `var'==.;
    };
reshape wide s w t k l naff nofdi, i(mneid nreg) j(cntrybemgrp) string;
sort mneid;
count if mneid~=.;
count;

merge mneid using "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-$waglvl-pt$par-af$aff";
tab _merge;
drop _merge;
sort mneid;
count if mneid~=.;
count;

* competitor regressors;
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-1996-costothr-$waglvl-pt$par-af$aff";
tab _merge;
foreach var in s k t l w wb {;
  foreach reg in $regagg {;
    qui gen double _avg_`var'_`reg' = `var'_othr_`reg' if _m==2; /* market average (mneid==0 in using data) */
    qui egen double _rpl_`var'_`reg' = max(_avg_`var'_`reg');
    qui replace `var'_othr_`reg' = _rpl_`var'_`reg' if `var'_othr_`reg'==.; /* replace missing competitor info with market average (mneid==0 in using data) */
    drop _avg_`var'_`reg' _rpl_`var'_`reg';
    };
  };
drop if mneid==0;
drop _merge;
sort mneid;
count if mneid~=.;
count;
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-1996-wwlocvars-pt$par-af$aff";
foreach var in employmt ln_dist ln_gdp ln_gdp_cap ln_consum_exp ln_cons_cap lh99_1 lh99_2 {;
  qui gen double _avg_`var' = `var'_othr if _m==2; /* market average (mneid==0 in using data) */
  qui egen double _rpl_`var' = max(_avg_`var');
  qui replace `var'_othr = _rpl_`var' if `var'_othr==.; /* replace missing competitor info with market average (mneid==0 in using data) */
  drop _avg_`var' _rpl_`var';
  };
drop if mneid==0;
tab _merge;
drop _merge;
sort mneid;
count if mneid~=.;
count;

* parent level regressors;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  foreach year in 1996 2000 {;
    local yr = substr("`year'",-2,2);
    drop chosen_`reg'_`year';  /* drop sample presence indicators, use population indicators below */
    rename ln_wagediff_`reg'_`year' ln_wdiff_`r2dg'`yr';
    };
  drop naff`r2dg'; /* drop sample affiliate counts, use population affiliate counts below */
  };
foreach year in 1996 2000 {;
  local yr = substr("`year'",-2,2);
  rename ln_inter_`year' ln_inter`yr';
  foreach var in employmt exports fixdasst assettot profits turnover equity liab caplabrat profeqtyrat intmed wb {;
    rename `var'_par_`year' `var'`yr';
    };
  };
drop w_HOM_2000; rename w_HOM_1996 w_HOM;  /* use 1998 BA wages (1996 proxied with 1998) */
replace w_HOM = exp(w_HOM);  /* plain wage */
local lbl : variable label w_HOM;
local lbl = subinstr("`lbl'","ln ","",.);
label var w_HOM "`lbl'";

* wage variable redefinitions: all wages in logs;
replace w_HOM = log(w_HOM);
local lbl : variable label w_othr_HOM;
local lbl = "ln `lbl'";
label var w_HOM "`lbl'";
foreach reg in $regagg {;
  replace w_othr_`reg' = log(w_othr_`reg');
  local lbl : variable label w_othr_`reg';
  local lbl = "ln `lbl'";
  label var w_othr_`reg' "`lbl'";
  };

* regional presence indicators and affiliate counts from population information;
gen byte iHO00 = 1;  /* Permanent presence in Home */
label var iHO00 "FDI presence HOM 00";
sort mneid;
merge mneid using `popinfo', nokeep;
tab _m;
drop _m;

foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  gen double i`r2dg'96_wHO = i`r2dg'96 * w_HOM;
  gen double i`r2dg'96_w`r2dg' = i`r2dg'96 * w_othr_`r2dg';
  };


/* extensive margin regressions */
/*------------------------------*/

foreach reg in $regagg {;
  forvalues xvars = `maxvars'(-1)0 {;
    local r2dg = substr("`reg'",1,2);

    * presence indicator ols with and without sector dummies, not saved as est mat;
    * xi: dprobit i`r2dg'00 iCE96 iDE96 iOI96 iWE96 ${par_`xvars'} i.sec1, asis;
    xi: reg i`r2dg'00 iCE96 iDE96 iOI96 iWE96 ${par_`xvars'} i.sec1;
    * dprobit i`r2dg'00 iCE96 iDE96 iOI96 iWE96 ${par_`xvars'}, asis;
    reg i`r2dg'00 iCE96 iDE96 iOI96 iWE96 ${par_`xvars'};

    * affiliate number regressions with and without sector dummies;
    xi: reg naff`r2dg' iCE96 iDE96 iOI96 iWE96 ${par_`xvars'} i.sec1;
    capture local chk = rowsof(olsnaff`r2dg'_b);  /* check whether matrix exists to add to */
    if _rc==111 {;
      est2vec olsnaff`r2dg', vars(iCE96 iDE96 iOI96 iWE96 ${par_`maxvars'} _Isec1_bem_1 _Isec1_bem_2 _Isec1_bem_3 _Isec1_bem_4 _Isec1_bem_5 _Isec1_bem_6 _Isec1_bem_7 _Isec1_bem_8 _Isec1_bem_9 _cons) name(`r2dg'`xvars'i);
      };
    else {;
      est2vec olsnaff`r2dg', addto(olsnaff`r2dg') name(`r2dg'`xvars'i);
      };
    reg naff`r2dg' iCE96 iDE96 iOI96 iWE96 ${par_`xvars'};
    est2vec olsnaff`r2dg', addto(olsnaff`r2dg') name(`r2dg'`xvars');

    * employment regressions with and without sector dummies;
    xi: reg l`r2dg' iCE96 iDE96 iOI96 iWE96 ${par_`xvars'} i.sec1;
    capture local chk = rowsof(olsempl`r2dg'_b);  /* check whether matrix exists to add to */
    if _rc==111 {;
      est2vec olsempl`r2dg', vars(iCE96 iDE96 iOI96 iWE96 ${par_`maxvars'} _Isec1_bem_1 _Isec1_bem_2 _Isec1_bem_3 _Isec1_bem_4 _Isec1_bem_5 _Isec1_bem_6 _Isec1_bem_7 _Isec1_bem_8 _Isec1_bem_9 _cons) name(`r2dg'`xvars'i);
      };
    else {;
      est2vec olsempl`r2dg', addto(olsempl`r2dg') name(`r2dg'`xvars'i);
      };
    reg l`r2dg' iCE96 iDE96 iOI96 iWE96 ${par_`xvars'};
    est2vec olsempl`r2dg', addto(olsempl`r2dg') name(`r2dg'`xvars');

    };
  };


/* matrix output */
/*---------------*/

foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  foreach type in b se e {;
    drop _all;
    matsave olsnaff`r2dg'_`type', p(estmat/v6/pt$par-af$aff-$waglvl/extmarg) t(double) replace;
    mat drop olsnaff`r2dg'_`type';
    drop _all;
    matsave olsempl`r2dg'_`type', p(estmat/v6/pt$par-af$aff-$waglvl/extmarg) t(double) replace;
    mat drop olsempl`r2dg'_`type';
    };
  };

log close;
cd "$root";
