*! version 1.1.2  14nov2006  by Marc Muendler  muendler@ucsd.edu

clear
set memory 400m
set matsize 800
set more off
capture log close

cd "$rootslct"

log using "logs/crossval-selct-2stp-$waglvl-pt$par-af$aff-cf-nonparam-allyrs.log", replace

*----------------------following code similar to translog-selct-2stp-cf-nonparam.do---------------------------------------------
*-----alteration: keep first-stage and cross validate---------------------------------------------------------------------------
*-----substitute: now for 00, ${yrdiff}yrlg for 96, /v6npfs for /v6np, mneid year for mneid ---------------------------------------------------
*-----substitute: Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs for Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam --

mat drop _all

local maxvars 4  /* longest used selection regressor varlist */
local surxno 15  /* number of SURE regressors per equation (excluding noFDI indicators, excluding adj. constant/ones and excluding propensity scores) */

adopath + "$root/%stata/ado"

#delimit ;


/* variable sets for selection estimation */
/*----------------------------------------*/

do $dp/!varsets-np.do;

*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;

/* data */
/*------*/

local usemissg 1; /* no `usemissg' loop */

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do-----------------------------------------;

capture mkdir "$rootslct/tex/v6npfs";
capture mkdir "$rootslct/estmat/v6npfs";
capture mkdir "$rootslct/tex/v6npfs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/byreg";
capture mkdir "$rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'";

*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;


use "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf", clear;
drop ln_inter_now;
rename ln_inter_${yrdiff} ln_inter;

foreach var in turnover employmt fixdasst equity liab caplabrat profits profeqtyrat intmed wb exports {;
  replace `var'_par_${yrdiff}yrlg=0 if `var'_par_${yrdiff}yrlg==.;
  };

if `usemissg' == 0 {;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    foreach var of varlist s`r2dg' w`r2dg' t`r2dg' k`r2dg' y`r2dg' cf??_w`r2dg' cf??_t`r2dg' cf??_k`r2dg' cf`r2dg' {;
      qui replace `var'=. if nofdi`r2dg'==1;
      };
    };
  };

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do--------------------------------------------------;
*-----substitute: now for 00, ${yrdiff}yrlg for 96, /n3npfs for /v6npr, mneid year for mneid --------------------------------------------------;
*-----substitute: Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs for Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam --;


/* nonparametric base variables for sureg estimation */
/*---------------------------------------------------*/

local dintact "ifdiCE ifdiDE ifdiWE ifdiOI";
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  local pscores`r2dg' "psc`r2dg' psc`r2dg'_`r2dg' psc`r2dg'_`r2dg'_`r2dg'";
  tokenize `pscores`r2dg'';
  local num : word count `pscores`r2dg'';
  local remtrm "ifdi`r2dg'";
  local multact : list dintact - remtrm;
  foreach dummy in `multact' {;
    forvalues i = 1/`num' {;
      local addtrm "``i''*`dummy'";
      local pscores`r2dg' "`pscores`r2dg'' `addtrm'";
      };
    };
  };
* disp "`pscoresCE'"; * disp "`pscoresDE'"; * disp "`pscoresOI'"; * disp "`pscoresWE'";
local pscno : word count `pscoresCE';
disp "`pscno'";


*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;

* note: data seection removed;
* note: matrix construction removed;

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do-----------------------------------------;

* Create selection polynomial regressors;
tokenize $selser;
local selno : word count $selser;
forvalues i = 1/`selno' {;
  local varname "``i''";
  local preptrm = subinstr(subinstr("``i''","w_","",.),"_"," ",.);
  * first-order terms;
  local var1 :  word 1 of `preptrm';
  if lower("`var1'")~="`var1'"  local var1 "w_othr_`var1'";
  else  local var1 "ln_`var1'";
  if substr("`var1'",-3,3)=="HOM"  local var1 = subinstr("`var1'","_othr","",.);
  * second-order terms;
  local var2 :  word 2 of `preptrm';
  if lower("`var2'")~="`var2'" & length("`var2'")>0  local var2 "w_othr_`var2'";
  if lower("`var2'")=="`var2'" & length("`var2'")>0  local var2 "ln_`var2'";
  if length("`var2'")>0  local var2 " * `var2'";
  if substr("`var2'",-3,3)=="HOM"  local var2 = subinstr("`var2'","_othr","",.);
  * third-order terms;
  local var3 :  word 3 of `preptrm';
  if lower("`var3'")~="`var3'" & length("`var3'")>0  local var3 "w_othr_`var3'";
  if lower("`var3'")=="`var3'" & length("`var3'")>0  local var3 "ln_`var3'";
  if length("`var3'")>0  local var3 " * `var3'";
  if substr("`var3'",-3,3)=="HOM"  local var3 = subinstr("`var3'","_othr","",.);
  if length("`var2'")>0 {;
    qui gen double `varname' = `var1'`var2'`var3';
    label var `varname' "(`varname')";
    };
  };
  * sector dummies;
  qui summ sec1_bem;
  local minsec = `r(min)'+1;
  local maxsec = `r(max)';
  local dumlst = "_Isec1_bem_`minsec'";
  local secdum = "_b[_Isec1_bem_`minsec']*_Isec1_bem_`minsec'";
  local secavgdum = "_b[_Isec1_bem_`minsec']*_MN_Isec1_bem_`minsec'";
  local minsec = `minsec' + 1;
  forvalues j = `minsec'/`maxsec' {;
    local dumlst "`dumlst' _Isec1_bem_`j'";
    local secdum "`secdum' + _b[_Isec1_bem_`j']*_Isec1_bem_`j'";
    local secavgdum "`secavgdum' + _b[_Isec1_bem_`j']*_MN_Isec1_bem_`j'";
    };
      
*----------------------above code identical to translog-selct-2stp-cf-nonparam.do-------------------------------------------;

*----------------------following code specific to crossval-selct-2stp-cf-nonparam-allyrs.do-----------------------------------------;

* remove observations with missing regressors;
foreach var of global par_1 {;
  drop if `var'==.;
  };

* number observations;
gen double obsid = _n;
label var obsid "Running observation number";
compress obsid;
local obstot = _N;

/* identify polynomial interaction terms */
/*---------------------------------------*/

local selser1 = subinstr(subinstr("${par_1}","_othr","",.),"ln_","",.);
local selser2 ""; /* second-order terms */
local cnt 0;
foreach var of local selser1 {;
  local cnt = `cnt' + 1;
  tokenize `selser1';
  local selno : word count `selser1';
  forvalues i = `cnt'/`selno' {;
    local addtrm = subinstr("`var'_``i''","_w_","_",.);
    local selser2 "`selser2' `addtrm'";
    };
  };
local selser3 ""; /* third-order terms */
local cnt 0;
foreach var of local selser1 {;
  tokenize `selser2';
  local selno : word count `selser2';
  forvalues i = 1/`selno' {;
    if index("`selser1'",substr("`var'",-3,3)) >= index("`selser1'",substr("``i''",-3,3)) {;
      local addtrm = subinstr("``i''_`var'","_w_","_",.);
      local selser3 "`selser3' `addtrm'";
      };
    };
  };

/* first step: non-parametric selection estimation */
/*-------------------------------------------------*/

local xvars = ${usexvar};
foreach reg in $regagg {;
 forvalues poly = 1/3 {;
  local r2dg = substr("`reg'",1,2);
  gen double psc`r2dg'poly`poly' = .;
  label var psc`r2dg'poly`poly' "Propensity score `r2dg' (polynomial `poly')";
  forvalues num = 1/`obstot' {;
    if `xvars'==0  local interact "";
    else           local interact "i`r2dg'${yrdiff}yrlg_wHO";

    * polynomial terms;
    local polytrms ${parnp_`xvars'};
    if `poly'<=2  local polytrms : list polytrms - selser3;
    if `poly'==1  local polytrms : list polytrms - selser2;
    
    * selection regressions without sector dummies (used for translog);
    * disp "polynomial terms: `polytrms'";
    qui regress i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' `polytrms' if obsid~=`num';

    * predict propensity score for omitted observation;
    if `xvars' == ${usexvar} {;   /* Only xvars ${usexvar} used for second stage */
      qui predict double _psc`r2dg', xb;
      qui replace psc`r2dg'poly`poly' = _psc`r2dg' if obsid==`num';
      drop _psc`r2dg';
      * summ psc`r2dg';
    };

    };  /* close observations loop */
   };  /* close poly loop */
  };  /* close reg loop */

/* collapse sums of squared errors to table */
/*------------------------------------------*/

keep mneid year i??now psc??poly?;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  forvalues poly = 1/3 {;
    gen double sqe`r2dg'poly`poly' = (i`r2dg'now - psc`r2dg'poly`poly')^2;
    };  /* close poly loop */
  };  /* close reg loop */
collapse (mean) sqe??poly?, fast;
gen byte _dummy = 1;
reshape long sqeCEpoly sqeDEpoly sqeOIpoly sqeWEpoly, i(_dummy) j(poly);
gen str6 _rowname = "poly_" + string(poly);
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  rename sqe`r2dg'poly sqe_`r2dg';
  };
drop _dummy poly;
save "$rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/byreg/crossval_tbl.dta", replace;
matload crossval_tbl, p($rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/byreg) over dropall;
est2tex crossval, ready replace dropall preserve path($rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/byreg) fancy;

log close;
cd "$root";
