*! version 1.1.3  30nov2008  by Marc Muendler  muendler@ucsd.edu

clear
set memory 400m
set matsize 800
set more off
capture log close

cd "$rootslct"

log using "logs/qic-selct-2stp-$waglvl-pt$par-af$aff-cf-nonparam-allyrs.log", replace

global poly 2  /* use only second-order polynomials; 1 2 3 possible */

capture program drop qicmnp
program define qicmnp

  args corr r2dg interact polytrms xvars
  local corropt "`corr'"
  if "`corr'"=="sta2"  local corropt "sta 2"

  quietly {
    capture xtgee i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' `polytrms', family(gaussian) i(mneid) t(year) corr(`corropt') iterate(250)
    if _rc~=0  exit
    tempname T t
    mat `T' = e(V)
    mat `T' = Ai * `T'
    mat `t' = trace(`T')
    scalar off = `t'[1,1]
    tempvar q1 mu
    predict double `mu', mu
    gen double `q1' = i`r2dg'now * log(`mu'/(1-`mu')) + log(1-`mu')
    summ `q1', meanonly
    }
    
    mat qic`xvars'_tbl[rownumb(qic`xvars'_tbl,"`corr'"),colnumb(qic`xvars'_tbl,"`r2dg'")] = 2*(off - r(sum))
end

*----------------------following code similar to translog-selct-2stp-cf-nonparam.do---------------------------------------------
*-----alteration: keep first-stage and cross validate---------------------------------------------------------------------------
*-----substitute: now for 00, ${yrdiff}yrlg for 96, /v6npfs for /v6, mneid year for mneid ---------------------------------------------------
*-----substitute: Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs for Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam --

mat drop _all

local maxvars 4  /* longest used selection regressor varlist */
local surxno 15  /* number of SURE regressors per equation (excluding noFDI indicators, excluding adj. constant/ones and excluding propensity scores) */

adopath + "$root/%stata/ado"

#delimit ;


/* variable sets for selection estimation */
/*----------------------------------------*/

do $dp/!varsets-np.do;

*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;

forvalues xvars = $usexvar/`maxvars' {;
  mat qic`xvars'_tbl = J(6,4,.);
  matrix rownames qic`xvars'_tbl = ind exch ar1 ar2 unst sta2;
  matrix colnames qic`xvars'_tbl = CE DE OI WE;
  };

/* data */
/*------*/

local usemissg 1; /* no `usemissg' loop */

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do-----------------------------------------;

capture mkdir "$rootslct/tex/v6npfs";
capture mkdir "$rootslct/estmat/v6npfs";
capture mkdir "$rootslct/tex/v6npfs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/byreg";
capture mkdir "$rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/translog`usemissg'";

*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;

use "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf", clear;
drop ln_inter_now;
rename ln_inter_${yrdiff} ln_inter;
tsset, clear;

foreach var in turnover employmt fixdasst equity liab caplabrat profits profeqtyrat intmed wb exports {;
  replace `var'_par_${yrdiff}yrlg=0 if `var'_par_${yrdiff}yrlg==.;
  };

* Create selection polynomial regressors;
tokenize $selser;
local selno : word count $selser;
forvalues i = 1/`selno' {;
  local varname "``i''";
  local preptrm = subinstr(subinstr("``i''","w_","",.),"_"," ",.);
  * first-order terms;
  local var1 :  word 1 of `preptrm';
  if lower("`var1'")~="`var1'"  local var1 "w_othr_`var1'";
  else  local var1 "ln_`var1'";
  if substr("`var1'",-3,3)=="HOM"  local var1 = subinstr("`var1'","_othr","",.);
  * second-order terms;
  local var2 :  word 2 of `preptrm';
  if lower("`var2'")~="`var2'" & length("`var2'")>0  local var2 "w_othr_`var2'";
  if lower("`var2'")=="`var2'" & length("`var2'")>0  local var2 "ln_`var2'";
  if length("`var2'")>0  local var2 " * `var2'";
  if substr("`var2'",-3,3)=="HOM"  local var2 = subinstr("`var2'","_othr","",.);
  * third-order terms;
  local var3 :  word 3 of `preptrm';
  if lower("`var3'")~="`var3'" & length("`var3'")>0  local var3 "w_othr_`var3'";
  if lower("`var3'")=="`var3'" & length("`var3'")>0  local var3 "ln_`var3'";
  if length("`var3'")>0  local var3 " * `var3'";
  if substr("`var3'",-3,3)=="HOM"  local var3 = subinstr("`var3'","_othr","",.);
  if length("`var2'")>0 {;
    qui gen double `varname' = `var1'`var2'`var3';
    label var `varname' "(`varname')";
    };
  };
  * sector dummies;
  qui summ sec1_bem;
  local minsec = `r(min)'+1;
  local maxsec = `r(max)';
  local dumlst = "_Isec1_bem_`minsec'";
  local secdum = "_b[_Isec1_bem_`minsec']*_Isec1_bem_`minsec'";
  local secavgdum = "_b[_Isec1_bem_`minsec']*_MN_Isec1_bem_`minsec'";
  local minsec = `minsec' + 1;
  forvalues j = `minsec'/`maxsec' {;
    local dumlst "`dumlst' _Isec1_bem_`j'";
    local secdum "`secdum' + _b[_Isec1_bem_`j']*_Isec1_bem_`j'";
    local secavgdum "`secavgdum' + _b[_Isec1_bem_`j']*_MN_Isec1_bem_`j'";
    };
      
* Identify polynomial interaction terms;
local selser1 = subinstr(subinstr("${par_1}","_othr","",.),"ln_","",.);
local selser2 ""; /* second-order terms */
local cnt 0;
foreach var of local selser1 {;
  local cnt = `cnt' + 1;
  tokenize `selser1';
  local selno : word count `selser1';
  forvalues i = `cnt'/`selno' {;
    local addtrm = subinstr("`var'_``i''","_w_","_",.);
    local selser2 "`selser2' `addtrm'";
    };
  };
local selser3 ""; /* third-order terms */
local cnt 0;
foreach var of local selser1 {;
  tokenize `selser2';
  local selno : word count `selser2';
  forvalues i = 1/`selno' {;
    if index("`selser1'",substr("`var'",-3,3)) >= index("`selser1'",substr("``i''",-3,3)) {;
      local addtrm = subinstr("``i''_`var'","_w_","_",.);
      local selser3 "`selser3' `addtrm'";
      };
    };
  };


/* first step: non-parametric selection estimation */
/*-------------------------------------------------*/

foreach reg in $regagg {;
  forvalues xvars = $usexvar/`maxvars' {;
    local r2dg = substr("`reg'",1,2);
    if `xvars'==0  local interact "";
    else           local interact "i`r2dg'${yrdiff}yrlg_wHO";

    * polynomial terms;
    local polytrms ${parnp_`xvars'};
    if ${poly}<=2  local polytrms : list polytrms - selser3;
    if ${poly}==1  local polytrms : list polytrms - selser2;

    * selection regressions without sector dummies (used for translog);
    * disp "polynomial terms: `polytrms'";
    xtgee i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' `polytrms', family(gaussian) i(mneid) t(year) corr(ind) iterate(250);
    mat Ai = e(V);
    mat Ai = syminv(Ai);

    foreach spec in ind exch ar1 ar2 unst sta2 {;
      qicmnp "`spec'" "`r2dg'" "`interact'" "`polytrms'" "`xvars'";
      };
      
    };  /* close xvars loop */
  };  /* close reg loop */


/* save matrix */
/*------------------------------------------*/

forvalues xvars = $usexvar/`maxvars' {;
  est2tex qic`xvars', ready replace dropall preserve path($rootslct/estmat/v6npfs/pt$par-af$aff-$waglvl-cf/byreg) fancy;
  };

log close;
cd "$root";
