*! version 1.2.6  14nov2006  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.1  15jun2009  by Marc Muendler  muendler@ucsd.edu

* identical to translog-selct-2stp-elasticities-cf-nonparam, except for
*   replace v6np with v6npr
*   replace -nonparam with -nonparam-relaxed

clear
clear
set more off
set matsize 400
adopath + "$root/%stata/ado"

cd "$rootslct"

capture log close
log using "logs/translog-selct-elasticities-$waglvl-pt$par-af$aff-cf-nonparam-relaxed-allyrs.log", replace

local waglvl "$waglvl"
local wagabr = subinstr("`waglvl'","wage","",.)
local wagabr = subinstr("`wagabr'","frm","",.)

foreach usemissg in $howmany {  /* begin `usemissg' loop */

capture mkdir "$rootslct/estmat/v6nprfs/pt$par-af$aff-$waglvl-cf/elast`usemissg'"

foreach elsttyp in Int Ext Tot { /* begin `base' loop */
  if "`elsttyp'"=="Int" {
   local base "coefmat`usemissg'`waglvl'_tbl - xmrmat`usemissg'`waglvl'_tbl"
   }
  if "`elsttyp'"=="Ext" {
   local base "xmrmat`usemissg'`waglvl'_tbl"
   }
  if "`elsttyp'"=="Tot" {
   local base "coefmat`usemissg'`waglvl'_tbl"
   }
  disp 
  disp in green "Data: " in yellow "`waglvl'" in green ". Margin: " in yellow "`elsttyp'"
  disp in green "-----------------------------"
  disp
  matload coefmat`usemissg'_tbl, p(estmat/v6nprfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg') over missing(.)
  mat rename coefmat`usemissg'_tbl coefmat`usemissg'`waglvl'_tbl
  local dim = rowsof(coefmat`usemissg'`waglvl'_tbl)
  matload xmrmat`usemissg'_tbl, p(estmat/v6nprfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg') over missing(.)
  mat rename xmrmat`usemissg'_tbl xmrmat`usemissg'`waglvl'_tbl 
  matload translog`usemissg'_b, p(estmat/v6nprfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg') over missing(.)
  mat rename translog`usemissg'_b trlg`usemissg'`waglvl'_b
  matload tmat`usemissg'_tbl, p(estmat/v6nprfs/pt$par-af$aff-`waglvl'-cf/translog`usemissg') over missing(.)
  mat rename tmat`usemissg'_tbl tmat`usemissg'`waglvl'_tbl

  * Share squares
  mat _Tsqmat = tmat`usemissg'`waglvl'_tbl[1,1..5] ' * tmat`usemissg'`waglvl'_tbl[1,1..5]

  * Allen-Uzawa elasticity matrix
  mat AUmat = `base' + _Tsqmat
  forvalues r = 2/`dim' { /* Fill lower-echelon entries */
  local maxcol = `r'-1
    forvalues m = 1/`maxcol' {
      mat AUmat[`r',`m'] = AUmat[`r',`m'] / _Tsqmat[`r',`m']
      }
    }
  forvalues m = 2/`dim' { /* Fill upper-echelon entries */
  local maxrow = `m'-1
    forvalues r = 1/`maxrow' {
      mat AUmat[`r',`m'] = AUmat[`r',`m'] / _Tsqmat[`r',`m']
      }
    }
  forvalues r = 1/`dim' {  /* Fill diagonal entries */
      mat AUmat[`r',`r'] = ( AUmat[`r',`r'] - sqrt(_Tsqmat[`r',`r']) ) / _Tsqmat[`r',`r']
    }

  if "`elsttyp'"=="Tot" {
  * Eigenvalues of Allen-Uzawa elasticity matrix, joint margins only
  matrix symeigen eigenvec`elsttyp'`usemissg'`waglvl' eigenval`elsttyp'`usemissg'`wagabr' = AUmat
  matname eigenval`elsttyp'`usemissg'`wagabr' eigenvalue, rows(1) explicit
  mat drop eigenvec`elsttyp'`usemissg'`waglvl'
  }

  * Calculate cross-price elasticity matrix
  mat Elast = `base' + _Tsqmat
  forvalues r = 2/`dim' { /* Fill lower-echelon entries */
  local maxcol = `r'-1
    forvalues m = 1/`maxcol' {
      mat Elast[`r',`m'] = Elast[`r',`m'] / sqrt(_Tsqmat[`r',`r'])
      }
    }
  forvalues m = 2/`dim' { /* Fill upper-echelon entries */
  local maxrow = `m'-1
    forvalues r = 1/`maxrow' {
      mat Elast[`r',`m'] = Elast[`r',`m'] / sqrt(_Tsqmat[`r',`r'])
      }
    }
  forvalues r = 1/`dim' {  /* Fill diagonal entries */
      mat Elast[`r',`r'] = Elast[`r',`r'] / sqrt(_Tsqmat[`r',`r']) - 1
    }
  mat rename Elast elast`elsttyp'`usemissg'`wagabr'_tbl

  * Morishima elasticity matrix
  mat MORImat = J(`dim',`dim',.)
  forvalues r = 1/`dim' {  /* Fill all entries */
    forvalues m = 1/`dim' {
      mat MORImat[`r',`m'] = elast`elsttyp'`usemissg'`wagabr'_tbl[`m',`r'] - elast`elsttyp'`usemissg'`wagabr'_tbl[`r',`r']
      }
    }
  
  * Transformed Morishima elasticity matrix
  mat TFMORImat = J(`dim',`dim',.)
  forvalues r = 1/`dim' {  /* Fill all entries */
    forvalues m = 1/`dim' {
      mat TFMORImat[`r',`m'] = 1 - (elast`elsttyp'`usemissg'`wagabr'_tbl[`m',`r'] - elast`elsttyp'`usemissg'`wagabr'_tbl[`r',`r'])
      }
    }

  * Check Allen-Uzawa matrix calculation
  mat AUchk = elast`elsttyp'`usemissg'`wagabr'_tbl
  forvalues r = 1/`dim' {  /* Fill all entries */
    forvalues m = 1/`dim' {
      mat AUchk[`r',`m'] = AUchk[`r',`m'] / sqrt(_Tsqmat[`m',`m'])
      }
    }
  if "`elsttyp'"=="Tot" { /* Allen-Uzawa only symmetic at joint margins */
    matrix symeigen VECchk VALchk = AUchk
    mat drop VECchk VALchk
    }
  mat AUchk = AUchk - AUmat
  
  * List and save matrices
  mat drop _Tsqmat tmat`usemissg'`waglvl'_tbl trlg`usemissg'`waglvl'_b coefmat`usemissg'`waglvl'_tbl xmrmat`usemissg'`waglvl'_tbl
  local colnames : colnames elast`elsttyp'`usemissg'`wagabr'_tbl
  local colnames = subinstr("`colnames'","s","mWage",.)
  local rownames : rownames elast`elsttyp'`usemissg'`wagabr'_tbl
  local rownames = subinstr("`rownames'","s","rLDem",.)
  foreach mat in AUchk AUmat MORImat TFMORImat elast`elsttyp'`usemissg'`wagabr'_tbl {
      matname `mat' `colnames', columns(1..`dim') explicit
      matname `mat' `rownames', rows(1..`dim') explicit
      }

  disp 
  disp in yellow "Check consistency of calculations. The following must be a zero matrix"
  mat list AUchk
  disp
  mat drop AUchk

  disp 
  disp in yellow "(Constant-output) cross-price elasticity matrix"
  mat list elast`elsttyp'`usemissg'`wagabr'_tbl
  qui matsave elast`elsttyp'`usemissg'`wagabr'_tbl, dropall p($rootslct/estmat/v6nprfs/pt$par-af$aff-$waglvl-cf/elast`usemissg') t(double) replace
  disp

  if "`elsttyp'"=="Tot" { /* Allen-Uzawa symmetric at joint margins overall */
  disp 
  disp in yellow "Eigenvalues of (constant-output) cross-price elasticity matrix"
  mat rename eigenval`elsttyp'`usemissg'`wagabr' eigenval`elsttyp'`usemissg'`wagabr'_tbl
  mat list eigenval`elsttyp'`usemissg'`wagabr'_tbl
  qui matsave eigenval`elsttyp'`usemissg'`wagabr'_tbl, dropall p($rootslct/estmat/v6nprfs/pt$par-af$aff-$waglvl-cf/elast`usemissg') t(double) replace
  disp
  }

  disp 
  disp in yellow "Allen-Uzawa elasticity matrix"
  mat rename AUmat aumat`elsttyp'`usemissg'`wagabr'_tbl
  mat list aumat`elsttyp'`usemissg'`wagabr'_tbl
  qui matsave aumat`elsttyp'`usemissg'`wagabr'_tbl, dropall p($rootslct/estmat/v6nprfs/pt$par-af$aff-$waglvl-cf/elast`usemissg') t(double) replace 
  disp

  disp 
  disp in yellow "Morishima elasticity matrix"
  mat rename MORImat mori`elsttyp'`usemissg'`wagabr'_tbl
  mat list mori`elsttyp'`usemissg'`wagabr'_tbl
  qui matsave mori`elsttyp'`usemissg'`wagabr'_tbl, dropall p($rootslct/estmat/v6nprfs/pt$par-af$aff-$waglvl-cf/elast`usemissg') t(double) replace 
  disp

  disp 
  disp in yellow "Transformed Morishima elasticity matrix"
  mat rename TFMORImat tfmori`elsttyp'`usemissg'`wagabr'_tbl
  mat list tfmori`elsttyp'`usemissg'`wagabr'_tbl
  qui matsave tfmori`elsttyp'`usemissg'`wagabr'_tbl, dropall p($rootslct/estmat/v6nprfs/pt$par-af$aff-$waglvl-cf/elast`usemissg') t(double) replace 
  disp

  * clean up
  mat drop elast`elsttyp'`usemissg'`wagabr'_tbl aumat`elsttyp'`usemissg'`wagabr'_tbl mori`elsttyp'`usemissg'`wagabr'_tbl tfmori`elsttyp'`usemissg'`wagabr'_tbl
  capture mat drop eigenval`elsttyp'`usemissg'`wagabr'_tbl 
  drop _all

 } /* end `base' loop */
} /* end `usemissg' loop */

log close
cd "$root"
