*! version 1.0.1  28may2005  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.7  21mar2006  by Marc Muendler  muendler@ucsd.edu

clear
set memory 400m
set matsize 700
set more off
capture log close

version 8

cd "$rootslct"

log using "logs/counterfact-ger-cf.log", replace

disp "Sample: " in yellow "$sample"
disp "Wage: " in yellow "$waglvl"

capture mkdir "$rootslct/tex/desc"

mat drop _all

/* Note: totelast`usemissg'_tbl and extelast`usemissg'_tbl expected to contain bootstrapped standard errors two rows below coefficients */
local totbelw = 1
local extbelw = 1
/* Note: intelast`usemissg'_tbl expected to contain bootstrapped standard errors one row below coefficients */
local intbelw = 2

adopath + "$root/%stata/ado"

* wage difference
local wagabr = subinstr(subinstr("$waglvl","wage","",.),"frm","",.)
est2extlbl, addto(wdiff`wagabr'ger00) intex($rootdo/%stata/rowlbl-fdiselct) p(tex/desc/wagediffs) replace
use "tex/desc/wagediffs/diffsger00-$waglvl", clear
rename _rowname rowname
gen str _rowname = "_wagesec_bem_" + string(rowname)
drop rowname
qui save wdiffger00$waglvl, replace
qui matload wdiffger00$waglvl, dropall over missing(.)
qui erase wdiffger00$waglvl.dta
mat rename wdiffger00$waglvl wdiff`wagabr'ger00_tbl
est2tex wdiff`wagabr'ger00, replace dropall preserve ready p(tex/desc/wagediffs) fancy digits(3)
clear

foreach usemissg in $howmany {

foreach margin in int ext tot {

* COUNTERFACTUAL CALCULATIONS

local country "ger"

* load variable names and save for est2tex
est2extlbl, addto(empl`country'pop) intex($rootdo/%stata/rowlbl-fdiselct) p(tex/desc/pt$par-af$aff) replace

local colmax : word count $reghomagg
local rowmax : word count $reghomagg

* aggregate employment by region (population)
use "tex/desc/pt$par-af$aff/employment-transf-population-2000", clear
decode cntrybemgrp, generate(_rowname)
keep _rowname pop_empl tot_empl_tf avg_empl_par_tf
qui save summ_empl_tbl, replace
qui matload summ_empl_tbl, dropall over missing(.)
erase summ_empl_tbl.dta
mat summ_empl_tbl = summ_empl_tbl'
matorder summ_empl_tbl, m(empl`country'pop) ifr(pop_empl tot_empl_tf avg_empl_par_tf)
* round pop_empl to full units (only) in output table
mat empl`country'pop_tbl = empl`country'pop
local rowsempl = rowsof(empl`country'pop_tbl)
local colsempl = colsof(empl`country'pop_tbl)
forvalues i = 1/`rowsempl' {
  forvalues j = 1/`colsempl' {
    if `i'~=rownumb(empl`country'pop_tbl,"avg_empl_par_tf")  mat empl`country'pop_tbl[`i',`j'] = int(empl`country'pop_tbl[`i',`j']+.5)
    }
  }
est2tex empl`country'pop, replace dropall preserve ready p(tex/desc/pt$par-af$aff) fancy thousep digits(1)
mat drop summ_empl_tbl empl`country'pop_tbl
mat empl`country'pop = empl`country'pop '
matkeep empl`country'pop, matrix(empl`country'pop) ifc(pop_empl) over

* cross-price substitution elasticity estimates
matload `margin'elast`usemissg'_tbl, p(tex/$sample/pt$par-af$aff-$waglvl-cf) over missing(.)
local keeprows = ""
tokenize HOM $regagg
local words : word count HOM $regagg
forvalues i = 1/`words' {
  local r2dg = substr("``i''",1,2)
  local keeprows = "`keeprows' rLDem`r2dg'"
  }
matkeep `margin'elast`usemissg'_tbl, matrix(elast`country') ifr(`keeprows')
matkeep `margin'elast`usemissg'_tbl, matrix(`margin'elast`country'pop`usemissg'_e) ifr("e(theta_N)")
matkeep `margin'elast`usemissg'_tbl, matrix(`margin'dspl`country'pop`usemissg'_e) ifr("e(theta_N)")

* mean wages and wage differentials by region (sample)
matload summ_translog`usemissg'_tbl, p(tex/$sample/pt$par-af$aff-$waglvl-cf) over dropall missing(.)
matkeep summ_translog`usemissg'_tbl, matrix(summ_translog`usemissg'_tbl) ifc(mean) over
mat wage`country' = J(1,`colmax',.)
matrix rownames wage`country' = wagelvl
local j 0
foreach reg in HOM $regagg {
  local j = `j' + 1
  local r2dg = substr("`reg'",1,2)
  mat wage`country'[1,`j'] = summ_translog1_tbl[rownumb(summ_translog1_tbl,"w`r2dg'"),1]
  matname wage`country' w`reg', columns(`j') explicit
  }
mat drop summ_translog`usemissg'_tbl
mat wagediff`country' = J(`colmax',`colmax',.)
local i 0
foreach regi in HOM $regagg {
  local i = `i' + 1
  local j 0
  foreach regj in HOM $regagg {
    local j = `j' + 1
    mat wagediff`country'[`i',`j'] = wage`country'[1,colnumb(wage`country',"w`regi'")]/wage`country'[1,colnumb(wage`country',"w`regj'")] - 1
    matname wagediff`country' wdiff`regj', columns(`j') explicit
    }
  matname wagediff`country' wdiff`regi', rows(`i') explicit
  }
mat drop wage`country'

* displacements undone counterfactually
* (note: wagediff`country' first row contains foreign wage increases to undo differential with lower-wage regions)
* (note: wagediff`country' first column contains home wage decreases to undo differential with lower-wage regions)
mat elast`country'pop = J(`colmax',`colmax',.)
local rownames : rowfullnames elast`country'
matrix rownames elast`country'pop = `rownames'
mat dspl`country'pop = elast`country'pop
local elastcols : colfullnames elast`country'
tokenize `elastcols'
forvalues j = 1/`colmax' {
  foreach reg in HOM $regagg {
  local r2dg = substr("`reg'",1,2)
    mat elast`country'pop[rownumb(elast`country'pop,"rLDem`r2dg'"),`j'] = empl`country'pop[rownumb(empl`country'pop,"`reg'"),1] * elast`country'[rownumb(elast`country',"rLDem`r2dg'"),`j'] /100  /* 100% percentage changes */
    matname elast`country'pop ``j''perc, columns(`j') explicit
    mat dspl`country'pop[rownumb(dspl`country'pop,"rLDem`r2dg'"),`j'] = wagediff`country'[rownumb(wagediff`country',"wdiff`reg'"),`j'] * empl`country'pop[rownumb(empl`country'pop,"`reg'"),1] * elast`country'[rownumb(elast`country',"rLDem`r2dg'"),`j']  /* closing the wage gap */
    matname dspl`country'pop ``j''nogap, columns(`j') explicit    
    }
  }
mat drop empl`country'pop wagediff`country' elast`country'

* reverse engineer pseudo standard errors for significance stars
foreach mat in elast dspl {
  mat rename `mat'`country'pop `margin'`mat'`country'pop`usemissg'_b
  local rownames : rowfullnames `margin'`mat'`country'pop`usemissg'_b
  local colnames : colfullnames `margin'`mat'`country'pop`usemissg'_b
  mat `margin'`mat'`country'pop`usemissg'_se = J(`colmax',`colmax',.)
  matrix rownames `margin'`mat'`country'pop`usemissg'_se = `rownames'
  matrix colnames `margin'`mat'`country'pop`usemissg'_se = `colnames'
  local i 0
  foreach regi in HOM $regagg {
    local i = `i' + 1
    local r2dgi = substr("`regi'",1,2)
    local j 0
    foreach regj in HOM $regagg {
      local j = `j' + 1
      local r2dgj = substr("`regj'",1,2)
      /* se = b / (b_orig / se_orig) */
      mat `margin'`mat'`country'pop`usemissg'_se[`i',`j'] = abs(`margin'`mat'`country'pop`usemissg'_b[`i',`j']) / ( abs(`margin'elast`usemissg'_tbl[rownumb(`margin'elast`usemissg'_tbl,"rLDem`r2dgi'"),colnumb(`margin'elast`usemissg'_tbl,"mWage`r2dgj'")])/`margin'elast`usemissg'_tbl[rownumb(`margin'elast`usemissg'_tbl,"rLDem`r2dgi'")+``margin'belw',colnumb(`margin'elast`usemissg'_tbl,"mWage`r2dgj'")] )
      }
    }
  }
mat drop `margin'elast`usemissg'_tbl

* round to full units
foreach mat in elast dspl {
  local j 0
  foreach regj in HOM $regagg {
    local j = `j' + 1
    local i 0
    foreach regi in HOM $regagg {
      local i = `i' + 1
      mat `margin'`mat'`country'pop`usemissg'_b[`i',`j'] = sign(`margin'`mat'`country'pop`usemissg'_b[`i',`j']) * int(abs(`margin'`mat'`country'pop`usemissg'_b[`i',`j'])+.5)
      mat `margin'`mat'`country'pop`usemissg'_se[`i',`j'] = sign(`margin'`mat'`country'pop`usemissg'_se[`i',`j']) * int(abs(`margin'`mat'`country'pop`usemissg'_se[`i',`j'])+.5)
      }
    local i 1
    mat `margin'`mat'`country'pop`usemissg'_e[`i',`j'] = sign(`margin'`mat'`country'pop`usemissg'_e[`i',`j']) * int(abs(`margin'`mat'`country'pop`usemissg'_e[`i',`j'])+.5)
    }
  }

* output
est2tex `margin'elast`country'pop`usemissg', replace dropall preserve mark(starb) path(tex/$sample/pt$par-af$aff-$waglvl-cf) fancy levels(90 95 99) thousep
est2tex `margin'dspl`country'pop`usemissg', replace dropall preserve mark(starb) path(tex/$sample/pt$par-af$aff-$waglvl-cf) fancy levels(90 95 99) thousep

} /* close `margin' loop */

* rename rows
foreach mat in elast dspl {
  local rowlab : rowfullnames tot`mat'`country'pop`usemissg'_b
  local words : word count `rowlab'
  tokenize `rowlab'
  local rownewlb = ""
  forvalues i = 1/`words' {
    local rownewlb "`rownewlb' ``i''nogap"
    }
  foreach type in b se {
    matname int`mat'`country'pop`usemissg'_`type' `rownewlb', rows(1..`words') explicit
    matname ext`mat'`country'pop`usemissg'_`type' `rownewlb', rows(1..`words') explicit
    matname tot`mat'`country'pop`usemissg'_`type' `rownewlb', rows(1..`words') explicit
    }
  }

* unified tables with both margins (two rows each for home and foreign)
foreach mat in elast dspl {
  foreach type in b se {
    * Counterfactual effect of foreign wage raise on home employment
    mat _`mat'`country'pop`usemissg'_int_`type' = int`mat'`country'pop`usemissg'_`type'[1,2..`colmax']  
    mat _`mat'`country'pop`usemissg'_ext_`type' = ext`mat'`country'pop`usemissg'_`type'[1,2..`colmax']  
    mat _`mat'`country'pop`usemissg'_tot_`type' = tot`mat'`country'pop`usemissg'_`type'[1,2..`colmax']  
    * Counterfactual effect of home wage drop on foreign employment
    mat _`mat'`country'pop`usemissg'_int_`type' = _`mat'`country'pop`usemissg'_int_`type' \ (-1)^(length("`type'")) * int`mat'`country'pop`usemissg'_`type'[2..`rowmax',1] '
    mat _`mat'`country'pop`usemissg'_ext_`type' = _`mat'`country'pop`usemissg'_ext_`type' \ (-1)^(length("`type'")) * ext`mat'`country'pop`usemissg'_`type'[2..`rowmax',1] '
    mat _`mat'`country'pop`usemissg'_tot_`type' = _`mat'`country'pop`usemissg'_tot_`type' \ (-1)^(length("`type'")) * tot`mat'`country'pop`usemissg'_`type'[2..`rowmax',1] '
    mat `mat'`country'pop`usemissg'_`type' = _`mat'`country'pop`usemissg'_tot_`type' \ _`mat'`country'pop`usemissg'_int_`type' \ _`mat'`country'pop`usemissg'_ext_`type'
    matrix roweq `mat'`country'pop`usemissg'_`type' = tot tot int int ext ext
    mat drop _`mat'`country'pop`usemissg'_int_`type' _`mat'`country'pop`usemissg'_ext_`type' _`mat'`country'pop`usemissg'_tot_`type'
    }
  mat `mat'`country'pop`usemissg'_e = tot`mat'`country'pop`usemissg'_e[1,2..`colmax'] \ int`mat'`country'pop`usemissg'_e[1,2..`colmax'] \ ext`mat'`country'pop`usemissg'_e[1,2..`colmax']
  matrix roweq `mat'`country'pop`usemissg'_e = tot int ext
  * round to full units
  local allrows = rowsof(`mat'`country'pop`usemissg'_b)
  local allcols = colsof(`mat'`country'pop`usemissg'_b)
  forvalues j = 1/`allcols' {
    forvalues i = 1/`allrows' {
      mat `mat'`country'pop`usemissg'_b[`i',`j'] = sign(`mat'`country'pop`usemissg'_b[`i',`j']) * int(abs(`mat'`country'pop`usemissg'_b[`i',`j'])+.5)
      mat `mat'`country'pop`usemissg'_se[`i',`j'] = sign(`mat'`country'pop`usemissg'_se[`i',`j']) * int(abs(`mat'`country'pop`usemissg'_se[`i',`j'])+.5)
      }
    local i 1
    mat `mat'`country'pop`usemissg'_e[`i',`j'] = sign(`mat'`country'pop`usemissg'_e[`i',`j']) * int(abs(`mat'`country'pop`usemissg'_e[`i',`j'])+.5)
    }
  est2extlbl, addto(`mat'`country'pop`usemissg') intex($rootdo/%stata/rowlbl-fdiselct) p(tex/$sample/pt$par-af$aff-$waglvl-cf) replace dropall
  * est2tex `mat'`country'pop`usemissg', replace dropall preserve mark(starb) p(tex/$sample/pt$par-af$aff-$waglvl-cf) fancy levels(90 95 99) thousep
  est2tex `mat'`country'pop`usemissg', replace dropall preserve mark(starse) p(tex/$sample/pt$par-af$aff-$waglvl-cf) fancy thousep levels(90 95 99) digits(0)
  }

* clean up
foreach margin in int tot {
  foreach type in b se e tbl {
    mat drop `margin'elast`country'pop`usemissg'_`type'
    mat drop `margin'dspl`country'pop`usemissg'_`type'
    }
  }

} /* close `usemissg' loop */

log close
cd "$root"
