*! version 1.0.3  13nov2008  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.2  20jun2009  by Marc Muendler  muendler@ucsd.edu

version 8.2
clear
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/make-regdata-cf-quarts-pt$par-af$aff.log", replace

capture program drop lblneutr
program define lblneutr
  syntax [varlist]
  foreach var of varlist `varlist' {
    local lbl : variable label `var'
    forvalues year = 1996/2001 {
      local lbl = trim(subinstr("`lbl'","`year'","",.))
      }
    foreach yr in 96 97 98 99 00 01 {
      local lbl = trim(subinstr("`lbl'","`yr'","",.))
      }
    label variable `var' "`lbl'"
    }
end

adopath + "$root/%stata/ado"

#delimit ;

/* prepare wage/employee at parent */
/*---------------------------------*/

tempfile rwag;
use firmid year avrg_wage_par using "$root/Xustan/ustan-fdi-match-wages-defl-15jun2009.dta";
duplicates drop;
gen lnw_HO = log(avrg_wage_par);
label var lnw_HO "Log Average HOM wage/employee";
keep if lnw_HO ~= .;
keep firmid year lnw_HO;
rename firmid mneid;
sort mneid year;
save `rwag';

/* data */
/*------*/

foreach tlogyear in 1998 1999 2000 2001 {;

tempfile mnes`tlogyear';
local tlogyr = substr("`tlogyear'",3,2);
local selyear = `tlogyear' - ${yrdiff};
local selyr = substr("`selyear'",3,2);

*----------------------following code identical to translog-selct-2stp-cf.do----------------------------------------------------;
*-----deactivate: `usemissg' ---------------------------------------------------------------------------------------------------;
*-----substitute: `tlogyear' for 2000, `tlogyr' for 00, ${yrdiff} for 4, `selyear' for 1996, `selyr' for 96, $dpref/ for $dp/---;
*-----substitute: /v6fs for /v6, chosen_`reg'_now for chosen_`reg'_`year' ------------------------------------------------------;
*-----substitute: Xdata/pop-reg-nonattrition-pt$par-af$aff-allyrs for Xdata/pop-reg-nonattrition-pt$par-af$aff -----------------;
*-----substitute: Xdata/mvprobit-outwfdi-ustan-`tlogyear'd$yrdiff... for Xdata/mvprobit-outwfdi-ustan-`tlogyear'... ------------;

tempfile popinfo;
use "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff-quarts", clear;
keep if year==`tlogyear';
keep mneid i*;  /* do not update sample-specific nofdi indicators for translog */
sort mneid;
compress;
save `popinfo';

if "$par" == "manf" | "$par" == "" {;
  };
if "$par" == "all" {;
  local howmany = "0 1";
  };

local usemissg 1;
* foreach usemissg in `howmany' {; /* begin `usemissg' loop */

use "$rootslct/Xdata/mneid-outwfdi-ustan-`tlogyear'-translog-$waglvl-pt$par-af$aff-quarts", clear;
drop naff l;

replace quartile=(substr(quartile,1,2));
replace quartile="Q9" if quartile=="";
foreach var in s w t k {;
  foreach reg in $regqrt {;
    local r2dg = substr("`reg'",1,2);
    qui gen double cf`r2dg'_`var' = cf`r2dg' * `var';
    };
  };
foreach reg in $regqrt {;
  local r2dg = substr("`reg'",1,2);
  qui gen y`r2dg' = cf`r2dg'_s;
  };

if `usemissg' == 0 {;
* keep usemissg observations as they are;
    drop nofdi;
    /* s:costShare y:Labor w:Wage t:Turnover("Output") k:Capital */
    reshape wide s w t k y?? cf??_w cf??_t cf??_k cf??_s cf??, i(mneid) j(quartile) string;
    };

if `usemissg' == 1 {;
* construct stacked system;
    foreach var of varlist s w t k y?? cf??_w cf??_t cf??_k cf??_s cf?? {;
        replace `var'=0 if `var'==.;
       };
    reshape wide s w t k y?? cf??_w cf??_t cf??_k cf??_s cf?? nofdi, i(mneid) j(quartile) string;
    };

foreach reg in HOM $regqrt {;
  local r2dg = substr("`reg'",1,2);
  capture rename y`r2dg'`r2dg' y`r2dg';  /* no yHO in quartile data (prep-translog-fdidata-quarts.do) */
  rename cf`r2dg'`r2dg' cf`r2dg';
  capture drop y`r2dg'??;  /* no yHO in quartile data (prep-translog-fdidata-quarts.do) */
  drop cf`r2dg'??;
  };
order mneid y??;

local waglvl "$waglvl";
if "`waglvl'"=="frmswewage"  local waglvl "frmowwwage";
sort mneid;
merge mneid using "$rootslct/Xdata/mvprobit-outwfdi-ustan-`tlogyear'd$yrdiff-`waglvl'-pt$par-af$aff-quarts";
tab _merge;
drop _merge;
sort mneid;

* competitor regressors;
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-`selyear'-costothr-$waglvl-pt$par-af$aff-quarts";
tab _merge;
foreach var in s k t l w wb {;
  foreach reg in $regqrt {;
    qui gen _avg_`var'_`reg' = `var'_othr_`reg' if _m==2; /* market average (mneid==0 in using data) */
    qui egen _rpl_`var'_`reg' = max(_avg_`var'_`reg');
    qui replace `var'_othr_`reg' = _rpl_`var'_`reg' if `var'_othr_`reg'==.; /* replace missing competitor info with market average (mneid==0 in using data) */
    drop _avg_`var'_`reg' _rpl_`var'_`reg';
    };
  };
drop if mneid==0;
drop _merge;
sort mneid;
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-`selyear'-wwlocvars-pt$par-af$aff-quarts";
* following code only used when "ustan-`selyear'-locvars" loaded (not "-wwlocvars")
* foreach reg in $regqrt {;
*   local r2dg = substr("`reg'",1,2);
*   foreach var in employmt ln_dist ln_gdp ln_gdp_cap ln_consum_exp ln_cons_cap lh99_1 lh99_2 {; 
*     qui gen _avg_`var' = `var'_othr_`reg' if _m==2; /* market average (mneid==0 in using data) */
*     qui egen _rpl_`var' = max(_avg_`var');
*     qui replace `var'_othr_`reg' = _rpl_`var' if `var'_othr_`reg'==.;  /* replace missing competitor info with market average (mneid==0 in using data) */
*     rename `var'_othr_`reg' `var'_othr_`r2dg'; 
*     drop _avg_`var' _rpl_`var';
*     };
*   };
drop if mneid==0;
tab _merge;
drop _merge;
sort mneid;

*----------------------above code identical to prep-mvprobit-med-wagediff.do---------------------------------------------;

* parent level regressors;
foreach reg in $regqrt {;
  local r2dg = substr("`reg'",1,2);
  drop chosen_`reg'_now chosen_`reg'_${yrdiff}yrlg;  /* drop sample presence indicators, use population indicators below */
  };
drop w_HOM_now w_othr_HOM ln_wagediff*; rename w_HOM_${yrdiff}yrlg w_HOM;
replace w_HOM = exp(w_HOM);  /* plain wage */
local lbl : variable label w_HOM;
local lbl = subinstr("`lbl'","ln ","",.);
label var w_HOM "`lbl'";

* wage variable redefinitions: all wages for location selection in 1,000 EUR;
replace w_HOM = w_HOM/1000;
local lbl : variable label w_HOM;
local lbl = "`lbl' [Thd EUR]";
label var w_HOM "`lbl'";
foreach reg in $regqrt {;
  replace w_othr_`reg' = w_othr_`reg'/1000;
  local lbl : variable label w_othr_`reg';
  local lbl = "`lbl' [Thd EUR]";
  label var w_othr_`reg' "`lbl'";
  };

* wage variable redefinitions: all wages for location selection not in logs (plain);
* replace w_HOM = log(w_HOM);
* local lbl : variable label w_HOM;
* local lbl = "ln `lbl'";
* label var w_HOM "`lbl'";
* foreach reg in $regqrt {;
*   replace w_othr_`reg' = log(w_othr_`reg');
*   local lbl : variable label w_othr_`reg';
*   local lbl = "ln `lbl'";
*   label var w_othr_`reg' "`lbl'";
*   };

* regional presence indicators and affiliate counts from population information;
gen byte iHOnow = 1;  /* Permanent presence in Home */
label var iHOnow "Presence HOM  current year";
sort mneid;
merge mneid using `popinfo', nokeep;
tab _m;
drop _m;

lblneutr *;
sort mneid;
gen year = `tlogyear';
label var year "Year (production, selection: -$yrdiff)";

save `mnes`tlogyear'';

};  /* close `tlogyear' loop */

use `mnes1998';
forvalues tlogyear = 1999/2001 {;
  append using `mnes`tlogyear'';
  };

foreach reg in $regqrt {;
  local r2dg = substr("`reg'",1,2);
  gen double i`r2dg'${yrdiff}yrlg_wHO = i`r2dg'${yrdiff}yrlg * w_HOM;
  gen double i`r2dg'${yrdiff}yrlg_w`r2dg' = i`r2dg'${yrdiff}yrlg * w_othr_`r2dg';
  label var i`r2dg'${yrdiff}yrlg_wHO     "Past Pres. `r2dg' X wage HO";
  label var i`r2dg'${yrdiff}yrlg_w`r2dg' "Past Pres. `r2dg' X wage `r2dg'";
  };

* parent wage;
sort mneid year;
qui count;
local chkn = `r(N)';
merge mneid year using `rwag', nokeep;
qui count;
if `r(N)'~=`chkn'  STOP;
tab _merge;
drop _merge;

* affiliate wages;
sort sec1_bem;
merge sec1_bem using "tex/desc/wagediffs/swediffs-$waglvl-1998-quartile-quarts.dta", nokeep;
tab _m;
drop _m;

* impute affiliate wages from current MNE wage premia by sector (Swedish MNEs);
foreach reg in $regqrt {;
  local r2dg = substr("`reg'",1,2);
  gen double lnw_`r2dg' = w`r2dg' + wdif`reg';  /* wdif`reg' is log wage premium */
  label var lnw_`r2dg' "Log imputed `reg' wage";
  drop wdif`reg';
  };

sort mneid year;
compress;
save "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf-quarts", replace;

log close;
cd "$root";
