!* version 1.1.1  19sep2008  by Marc Muendler  muendler@ucsd.edu

clear
set memory 500m
set more off
capture log close

cd "$rootslct"
log using "logs/prep-wages-$waglvl.log", replace


* External data preperation */
/*---------------------------*/

tempfile iso3buba cntrgrpbem

use "$root/conc/fdi-iso-country", clear
rename buba country
keep iso3code country 
sort country
compress
save `iso3buba'

use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'


/* Wage data at Parent Host-country Year level */
/*---------------------------------------------*/

foreach year in 1996 1997 1998 1999 2000 2001 {

local tlogyear = `year'
local tlogyr = substr("`tlogyear'",3,2)
local selyear = `tlogyear' - ${yrdiff}
if `selyear' < 1996  local selyr 1996
local selyr = substr("`selyear'",3,2)

global tlogyear = `tlogyear'
global selyear  = `selyear'
local wfl = substr("${waglvl}",4,3)
if "`wfl'"=="swe"  local wfl "oww"
global year `year'
* extra years for compatibility with prep-mvprobit-med-wagediff-allyrs.do and %40/prep-translog-fdidata.do
tempfile `wfl'`selyr' `wfl'99 `wfl'`tlogyr' hom`wfl'`selyr' hom`wfl'99 hom`wfl'`tlogyr' homsecwag swe98 homswe98
global `wfl'`selyr' "``wfl'`selyr''"
global `wfl'99 "``wfl'99'"
global `wfl'`tlogyr' "``wfl'`tlogyr''"
global swe98 "`swe98'"
global hom`wfl'`selyr' "`hom`wfl'`selyr''"
global hom`wfl'99 "`hom`wfl'99'"
global hom`wfl'`tlogyr' "`hom`wfl'`tlogyr''"
global homswe98 "`homswe98'"
global homsecwag "`homsecwag'"
do $dpref/#translog-`wfl'wages.do

use firmid ustan nace1 sec1_bem country year employmt employmt_par wb_par wb_ppp using "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff-allyrs" if year==`year', clear

order firmid ustan nace1 sec1_bem country year
sort country
merge country using `iso3buba', nokeep
tab _m
drop _m
sort country
merge country using `cntrgrpbem', nokeep
tab _m
keep firmid ustan iso3code country cntrygrp_bem nace1 sec1_bem year employmt_par employmt wb_par wb_ppp
order firmid ustan iso3code country cntrygrp_bem nace1 sec1_bem year employmt_par employmt wb_par wb_ppp


* Apply BEM cntrybemgrp definitions
/*-----------------------
 WEU: EMU (3), OWE (6);
 OIN: OIN (5);
 CEE: CEE (2); 
 DEV: APC (1), ODV (4) and RCA (7)
 --------------------------------------------*/
tab cntrygrp_bem
order firmid ustan country cntrygrp_bem
gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
label var cntrybemgrp "Country group BEM"
rename cntrybemgrp _cntrybemgrp
encode _cntrybemgrp, gen(cntrybemgrp) label(cntrybem)
drop _cntrybemgrp


/* Merge external wage data, keep only relevant year */
/*---------------------------------------------------*/

if substr("$waglvl",4,3)=="oww" | substr("$waglvl",4,3)=="ubs" | substr("$waglvl",4,3)=="uno" {  /* wb_par wb_ppp wage_par wage_ppp mhomwage */
  do $dpref/#translog-yearselect-wages.do
  }
if substr("$waglvl",4,3)=="swe" {  /* wb_par wb_ppp wage_par wage_ppp */
  do $dpref/#translog-avgswe-wages.do
  }
if substr("$waglvl",4,3)=="mne" {  /* wb_par wb_ppp wage_par wage_ppp */
  gen wage_ppp = wb_ppp / employmt
  gen wage_par = wb_par / employmt_par 
  }
  
keep firmid ustan year country cntrybemgrp iso3code nace1 sec1_bem employmt_par employmt wb_par wb_ppp wage_par wage_ppp 
order firmid ustan year country cntrybemgrp iso3code nace1 sec1_bem employmt_par employmt wb_par wb_ppp wage_par wage_ppp 
sort firmid country year

* Transform data to MNE level
* A dataset with R+1 lines per firm results, where R is the number of foreign in which the MNE operates and "1" stands for Home

rename firmid firm

tempfile hom
preserve
     keep if employmt_par~=.
     keep firm nace1 sec1_bem employmt_par wage_par wb_par
     gen byte cntrybemgrp = 0
     foreach var in employmt wage wb { 
       rename `var'_par `var'
       }
     duplicates drop
     duplicates tag firm, gen(_chk)
     count if _chk>=1
     if `r(N)' > 0 {
       disp as err "MNEs with contradictory home information"
       STOP
       }
     drop _chk
     compress
     sort firm
     save `hom'
 restore
     keep firm nace1 sec1_bem cntrybemgrp country employmt wage_ppp wb_ppp
     foreach var in wage wb {
       rename `var'_ppp `var'
       }
     duplicates drop
     compress
     sort firm
append using `hom'
label define cntrybem 0 "HOM", modify


/* Construct wage levels as in %44/prep-translog-fdidata-allyrs.do */
/*-----------------------------------------------------------------*/

# delimit ;

if substr("$waglvl",1,6)=="frmmne" {;
  keep if wb~=.;
  drop wage;
  gen wage = wb/employmt;
  drop wb;
};

if substr("$waglvl",1,3)=="frm" {;
  keep if wage~=.;
  gen wsum = wage * employmt;
  sort firm cntrybemgrp;

  * firm-specific wage and factor sums by region;
  by firm cntrybemgrp: egen reg_employmt=sum(employmt);
  by firm cntrybemgrp: egen reg_wsum=sum(wsum);

  * firm-specific wage sum worldwide;
  by firm: egen world_wsum=sum(wsum);

  * firm-specific wage by region;
  gen reg_wage = reg_wsum / reg_employmt;

  * firm-specific wage by region;
  bysort firm cntrybemgrp: keep if _n==1;
  keep reg* firm sec1_bem cntrybemgrp;
};

if substr("$waglvl",1,6)=="regmne" {;
  keep if wb_ppp~=.;
  drop wage;
  gen wage = wb_ppp/employmt;
  drop wb_ppp;
};

if substr("$waglvl",1,3)=="reg" {;
  keep if wage~=.;
  * firm-specific variables and median wages by region (median wages based on firm-level frequencies);
  collapse (sum) reg_employmt=employmt (median) reg_wage=wage, by(firm sec1_bem cntrybemgrp) fast;

  * firm-specific wage sum worldwide;
  gen reg_wsum = reg_wage * reg_employmt;
  by firm: egen world_wsum=sum(reg_wsum);

  bysort firm cntrybemgrp: keep if _n==1;
  keep reg* firm sec1_bem cntrybemgrp;
  drop reg_wsum;
};

  rename reg_wage     w;
  rename reg_employmt l;

keep w l firm sec1_bem cntrybemgrp;

fillin firm cntrybemgrp;

bysort firm: egen nobs=count(cntrybemgrp);
tab nobs;
count if nobs~=5;
    if `r(N)' > 0 {;
        disp as err "wrong number of observations";
        STOP;
        };
drop nobs;

rename firm firmid;
sort firmid;
by firmid: egen _sec = mean(sec1_bem);
replace sec1_bem = _sec if sec1_bem==.;
tab _sec;
drop _sec;


/* Clean-up */
by firmid: egen nreg=sum(_fillin);
replace nreg=5-nreg;
drop if nreg==1; /* drop all MNEs that have only data for one region, including home */
rename _fillin nofdi;
rename cntrybemgrp _cntrybemgrp;
decode _cntrybemgrp, gen(cntrybemgrp);
drop _cntrybemgrp;

qui do "$root/conc/secbem.do";
label values sec1_bem secbem;
compress;
order firmid cntrybemgrp;
sort firmid cntrybemgrp;

order firmid cntrybemgrp w l;
label var w "Wage rate";
label var l "Employment";
label var nofdi "Indic.: No FDI";
label var nreg "No. of active regions";

keep firmid cntrybemgrp w;
rename w w_;
reshape wide w_, i(firmid) j(cntrybemgrp) string;
foreach reg in $reghomagg {;
  label var w_`reg' "Wage `reg'";
  };
gen int year = `year';
label var year "Calendar Year";
order firmid year w_HOM w_CEE w_DEV w_OIN w_WEU;
compress;
sort firmid year;

save "Xdata/mneid-cafege-wages-`year'-$waglvl", replace; 

#delimit cr; 

} /* end year loop */


log close
cd "$root"
