*! version 1.0.2  12feb2008  by Marc Muendler  muendler@ucsd.edu
*! version 1.1.2  09sep2009  by Marc Muendler  muendler@ucsd.edu

clear
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/reg-as-konings-marin-$waglvl-pt$par-af$aff-cf-allyrs.log", replace

adopath + "$root/%stata/ado"


/* data */
/*------*/

#delimit ;

capture mkdir "$rootslct/tex/v6kmfs";
capture mkdir "$rootslct/estmat/v6kmfs";
capture mkdir "$rootslct/tex/v6kmfs/pt$par-af$aff-$waglvl";
capture mkdir "$rootslct/estmat/v6kmfs/pt$par-af$aff-$waglvl";

* use "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf", clear;

foreach tlogyear in 1998 1999 2000 2001 {;

tempfile popinfo mnes`tlogyear';
use "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff-allyrs", clear;
keep if year==`tlogyear';
keep mneid i*;  /* do not update sample-specific nofdi indicators for translog */
sort mneid;
compress;
save `popinfo';
use "$rootslct/Xdata/mneid-outwfdi-ustan-`tlogyear'-translog-$waglvl-pt$par-af$aff", clear;
keep mneid cntrybemgrp l w t k nofdi;
* construct stacked system;
foreach var in l w t k {;
  replace `var'=0 if `var'==.;
  };
reshape wide l w t k nofdi, i(mneid) j(cntrybemgrp) string;
* regional presence indicators and affiliate counts from population information;
gen byte iHOnow = 1;  /* Permanent presence in Home */
label var iHOnow "Presence HOM  current year";
sort mneid;
merge mneid using `popinfo', nokeep;
tab _m;
drop _m;
gen int year = `tlogyear';
save `mnes`tlogyear'';

};  /* close `tlogyear' loop */

use `mnes1998';
forvalues tlogyear = 1999/2001 {;
  append using `mnes`tlogyear'';
  };
sort mneid year;
compress;
label var year "Calendar Year";

foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  gen double i`r2dg'${yrdiff}yrlg_wHO = i`r2dg'${yrdiff}yrlg * wHOM;
  gen double i`r2dg'${yrdiff}yrlg_w`r2dg' = i`r2dg'${yrdiff}yrlg * w`reg';
  };


/* single home labor demand equation */
/*-----------------------------------*/

* for comparison: ;
* sureg (sCE: yCE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiOI nofdiWE cfCE mCE, nocons)
*       (sDE: yDE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiOI nofdiWE cfDE mDE, nocons)
*       (sOI: yOI = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiOI nofdiWE cfOI mOI, nocons)
*       (sWE: yWE = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiOI nofdiWE cfWE mWE, nocons)
*       , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate($maxiter);
* *     (sHO: yHO = cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiOI nofdiWE cfHO mHO, nocons); /* left-out equation */

* for initial table;
xtreg lHOM wHO wCE wDE wOI wWE tHO, fe i(mne);
est2vec regkm, e(N r2 r2_w F df_m) vars(wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE iCEnow iDEnow iOInow iWEnow iHO${yrdiff}yrlg iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg iCE${yrdiff}yrlg_wHO iCE${yrdiff}yrlg_wCE iDE${yrdiff}yrlg_wDE iOI${yrdiff}yrlg_wOI iWE${yrdiff}yrlg_wWE) name(fe);
reg lHOM wHO wCE wDE wOI wWE tHO;
est2vec regkm, addto(regkm) name(reg);
xtreg lHOM wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE, fe i(mne);
est2vec regkm, addto(regkm) name(fe_tk);
reg lHOM wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE;
est2vec regkm, addto(regkm) name(reg_tk);
xtreg lHOM wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE iCEnow iDEnow iOInow iWEnow iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg, fe i(mne);
est2vec regkm, addto(regkm) name(fe_tk_i);
xtreg lHOM wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE iCEnow iDEnow iOInow iWEnow iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg, fe i(mne);
est2vec regkm, addto(regkm) name(fe_tk_i_ilg);
xtreg lHOM wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg, fe i(mne);
est2vec regkm, addto(regkm) name(fe_tk_ilg);
reg lHOM wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg;
est2vec regkm, addto(regkm) name(reg_tk_ilg);
xtreg lHOM wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE iCEnow iDEnow iOInow iWEnow iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg iCE${yrdiff}yrlg_wHO iCE${yrdiff}yrlg_wCE iDE${yrdiff}yrlg_wDE iOI${yrdiff}yrlg_wOI iWE${yrdiff}yrlg_wWE, fe i(mne);
est2vec regkm, addto(regkm) name(fe_tk_i_ilg_ilgw);
reg lHOM wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE iCEnow iDEnow iOInow iWEnow iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg iCE${yrdiff}yrlg_wHO iCE${yrdiff}yrlg_wCE iDE${yrdiff}yrlg_wDE iOI${yrdiff}yrlg_wOI iWE${yrdiff}yrlg_wWE;
est2vec regkm, addto(regkm) name(reg_tk_i_ilg_ilgw);
xtreg lHOM wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg iCE${yrdiff}yrlg_wHO iCE${yrdiff}yrlg_wCE iDE${yrdiff}yrlg_wDE iOI${yrdiff}yrlg_wOI iWE${yrdiff}yrlg_wWE, fe i(mne);
est2vec regkm, addto(regkm) name(fe_tk_ilg_ilgw);

* for Sascha table;
gen tWW = log(exp(tHO)+exp(tCE)+exp(tDE)+exp(tOI)+exp(tWE));
xtreg lHOM wHO wCE wWE tWW, fe i(mne);
est2vec regkm, addto(regkm) name(km_tbl4_fe);
reg lHOM wHO wCE wWE tWW;
est2vec regkm, addto(regkm) name(km_tbl4);
reg lHOM wHO wCE wWE tHO tCE tWE;
est2vec regkm, addto(regkm) name(km_tbl4_t);
reg lHOM wHO wCE wWE tHO tCE tWE kHO kCE kWE;
est2vec regkm, addto(regkm) name(km_tbl4_t_k);
reg lHOM wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE;
est2vec regkm, addto(regkm) name(km_tbl4_t_k_allreg);

* for Sascha table with augmented regressions;
gen tEU = log(exp(tHO)+exp(tCE)+exp(tWE));
xtreg lHOM wHO wCE wWE tHO iCEnow iWEnow, fe i(mne);
est2vec regkm, addto(regkm) name(kmi_tbl4_fe);
reg lHOM wHO wCE wWE tHO iCEnow iWEnow;
est2vec regkm, addto(regkm) name(kmi_tbl4);
reg lHOM wHO wCE wWE tHO tCE tWE iCEnow iWEnow;
est2vec regkm, addto(regkm) name(kmi_tbl4_t);
reg lHOM wHO wCE wWE tHO tCE tWE kHO kCE kWE iCEnow iWEnow;
est2vec regkm, addto(regkm) name(kmi_tbl4_t_k);
reg lHOM wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE iCEnow iDEnow iOInow iWEnow;
est2vec regkm, addto(regkm) name(kmi_tbl4_t_k_allreg);

foreach type in b se e {;
    matsave regkm_`type', p(estmat/v6kmfs/pt$par-af$aff-$waglvl) t(double) replace dropall;
    };

est2extlbl, addto(regkm) intex($rootdo/%stata/rowlbl-fdiselct) p(tex/v6kmfs/pt$par-af$aff-$waglvl) replace dropall;
est2tex regkm, replace dropall preserve mark(starse) path(tex/v6kmfs/pt$par-af$aff-$waglvl) fancy levels(90 95 99);

* clean up;
foreach type in b se e tbl {;
    mat drop regkm_`type';
    };


log close;
cd "$root";
