*! version 1.0.1  09jun2009  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.2  21jun2009  by Marc Muendler  muendler@ucsd.edu

clear
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/wage-process-asinprobit-pt$par-af$aff-$waglvl-allyrs.log", replace

mat drop _all

local maxvars 4  /* longest used probit varlist */
local surxno 15  /* number of SURE regressors per equation (excluding noFDI indicators, excluding adj. constant/ones and mills ratio) */

adopath + "$root/%stata/ado"

#delimit ;


/* variable sets for probit estimation */
/*-------------------------------------*/

do $dpfsref/!varsets.do;


/* data */
/*------*/

foreach usemissg in $howmany {; /* begin `usemissg' loop */

capture mkdir "$rootslct/tex/v6fs";
capture mkdir "$rootslct/estmat/v6fs";
capture mkdir "$rootslct/tex/v6fs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-cf/byreg";

use "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf", clear;

if `usemissg' == 0 {;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    foreach var of varlist s`r2dg' w`r2dg' t`r2dg' k`r2dg' y`r2dg' cf??_w`r2dg' cf??_t`r2dg' cf??_k`r2dg' cf`r2dg' {;
      qui replace `var'=. if nofdi`r2dg'==1;
      };
    };
  };

* obtain additional lag of competitor wages by MNE;
preserve;
foreach tlogyear in 1998 1999 2000 2001 {;
local tlogyr = substr("`tlogyear'",3,2);
local selyear = `tlogyear' - ${yrdiff} - ${yrdiff};  * 4-year lag for ${yrdiff}=2;
tempfile wlag`selyear';
if `selyear'>=1996 {;
  use "$rootslct/Xdata/mneid-outwfdi-ustan-`selyear'-costothr-$waglvl-pt$par-af$aff", clear;
  keep mneid w_othr_CEE w_othr_DEV w_othr_HOM w_othr_OIN w_othr_WEU;
  foreach reg in $reghomagg {;
    rename w_othr_`reg' w_othr_`reg'_lag2_`tlogyr';
    label var w_othr_`reg'_lag2_`tlogyr' "Wage rate `reg', additional lag";
    };
  sort mneid;
  save `wlag`selyear'';
  };
};
restore;
foreach tlogyear in 1998 1999 2000 2001 {;
local selyear = `tlogyear' - ${yrdiff} - ${yrdiff};  * 4-year lag for ${yrdiff}=2;
sort mneid;
if `selyear'>=1996  merge mneid using `wlag`selyear'';
capture drop _merge;
};
foreach reg in $reghomagg {;
  gen w_othr_`reg'_lag2 = .;
  label var w_othr_`reg'_lag2 "Wage rate `reg', additional lag";
  foreach tlogyear in 1998 1999 2000 2001 {;
  local tlogyr = substr("`tlogyear'",3,2);
    if `tlogyear'>=2000  replace w_othr_`reg'_lag2 = w_othr_`reg'_lag2_`tlogyr' if year==`tlogyear';
    };
  local r2dg = substr("`reg'",1,2);
  gen expw`r2dg' = exp(w`r2dg');
  };


/* first step: wage process instead of probit estimation */
/*-------------------------------------------------------*/

foreach reg in $regagg {;
  * forvalues xvars = `maxvars'(-1)0 {;
  forvalues xvars = ${usexvar}/${usexvar} {;
    local r2dg = substr("`reg'",1,2);
    tempvar pxb;
    tempname chk;
    if `xvars'==0  local interact "";
    else           local interact "i`r2dg'${yrdiff}yrlg_wHO";

    * wage process regression with sector dummies;
    xi: reg expw`r2dg' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' ${par_`xvars'} i.sec1;
    capture local chkcol = colsof(wageproc`r2dg'_b);  /* check whether matrix exists to add to */
    if _rc==111 {;
      est2vec wageproc`r2dg', vars(iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg i`r2dg'${yrdiff}yrlg_wHO ${par_`maxvars'}  w_othr_HOM_lag2 w_othr_CEE_lag2 w_othr_DEV_lag2 w_othr_OIN_lag2 w_othr_WEU_lag2 _Isec1_bem_1 _Isec1_bem_2 _Isec1_bem_3 _Isec1_bem_4 _Isec1_bem_5 _Isec1_bem_6 _Isec1_bem_7 _Isec1_bem_8 _Isec1_bem_9 _cons) e(N ll chi2 df_m r2_p pbar xbar) name(`r2dg'`xvars'i);
      };
    else {;
      est2vec wageproc`r2dg', addto(wageproc`r2dg') name(`r2dg'`xvars'i);
      };
    xi: reg expw`r2dg' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' ${par_`xvars'} w_othr_HOM_lag2 w_othr_CEE_lag2 w_othr_DEV_lag2 w_othr_OIN_lag2 w_othr_WEU_lag2 i.sec1;
    est2vec wageproc`r2dg', addto(wageproc`r2dg') name(`r2dg'`xvars'i_addllag);

    * probit regressions without sector dummies (used for translog);
    * qui reg expw`r2dg' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' ${par_`xvars'};
    * qui predict linres`r2dg', res;
    reg expw`r2dg' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' ${par_`xvars'};
    est2vec wageproc`r2dg', addto(wageproc`r2dg') name(`r2dg'`xvars');
    reg expw`r2dg' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' ${par_`xvars'} w_othr_HOM_lag2 w_othr_CEE_lag2 w_othr_DEV_lag2 w_othr_OIN_lag2 w_othr_WEU_lag2;
    est2vec wageproc`r2dg', addto(wageproc`r2dg') name(`r2dg'`xvars'_addllag);
    dprobit i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' ${par_`xvars'}, asis iterate($maxiter);
    est2vec wageproc`r2dg', addto(wageproc`r2dg') name(dprbt_`r2dg'`xvars') altvec(dfdx se_dfdx);
    dprobit i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' ${par_`xvars'} w_othr_HOM_lag2 w_othr_CEE_lag2 w_othr_DEV_lag2 w_othr_OIN_lag2 w_othr_WEU_lag2, asis iterate($maxiter);
    est2vec wageproc`r2dg', addto(wageproc`r2dg') name(dprbt_`r2dg'`xvars'_addllag) altvec(dfdx se_dfdx);

    * note: probit regressions without sector dummies are relevant ones;
    * in two-step estimator, inverse of Mills' ratios and delta from probit regression without sector dummies;

    };
  };


/* matrix output */
/*---------------*/

foreach reg in $regagg {;
  disp;
  local r2dg = substr("`reg'",1,2);
  foreach type in b se e {;
    drop _all;
    matsave wageproc`r2dg'_`type', p(estmat/v6fs/pt$par-af$aff-$waglvl-cf/byreg) t(double) replace;
    };
  };

/* tex output */
/*------------*/

est2extlbl, addto(wageproc) intex($rootdo/%stata/rowlbl-fdiselct) p(tex/v6fs/pt$par-af$aff-$waglvl-cf) replace dropall;
foreach type in b se e {;
  mat wageproc_`type' = wageprocCE_`type' , wageprocDE_`type' , wageprocOI_`type' , wageprocWE_`type';
  matorder wageproc_`type', m(wageproc_t_`type') ifc(CE3 DE3 OI3 WE3);
  if "`type'"~="e"  matorder wageproc_t_`type', m(wageproc_t_`type') ifr(w_HOM w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU) over;
  matorder wageproc_`type', m(wageproc_b_`type') ifc(CE3_addllag DE3_addllag OI3_addllag WE3_addllag);
  if "`type'"~="e"  matorder wageproc_b_`type', m(wageproc_b_`type') ifr(w_HOM w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU w_othr_HOM_lag2 w_othr_CEE_lag2 w_othr_DEV_lag2 w_othr_OIN_lag2 w_othr_WEU_lag2) over;
  };
est2one wageproc_t;
est2one wageproc_b;
mat wageproc_tbl = wageproc_t_tbl \ wageproc_b_tbl;
mat drop wageproc_t_tbl wageproc_b_tbl;
est2tex wageproc, ready dropall path(tex/v6fs/pt$par-af$aff-$waglvl-cf) fancy mark(starse) levels(90 95 99) replace;

est2extlbl, addto(wageproc_dprbt) intex($rootdo/%stata/rowlbl-fdiselct) p(tex/v6fs/pt$par-af$aff-$waglvl-cf) replace dropall;
foreach type in b se e {;
  mat wageproc_`type' = wageprocCE_`type' , wageprocDE_`type' , wageprocOI_`type' , wageprocWE_`type';
  matorder wageproc_`type', m(wageproc_t_`type') ifc(dprbt_CE3 dprbt_DE3 dprbt_OI3 dprbt_WE3) over;
  if "`type'"~="e"  matorder wageproc_t_`type', m(wageproc_t_`type') ifr(w_HOM w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU) over;
  matorder wageproc_`type', m(wageproc_b_`type') ifc(dprbt_CE3_addllag dprbt_DE3_addllag dprbt_OI3_addllag dprbt_WE3_addllag) over;
  if "`type'"~="e"  matorder wageproc_b_`type', m(wageproc_b_`type') ifr(w_HOM w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU w_othr_HOM_lag2 w_othr_CEE_lag2 w_othr_DEV_lag2 w_othr_OIN_lag2 w_othr_WEU_lag2) over;
  mat drop wageprocCE_`type' wageprocDE_`type' wageprocOI_`type' wageprocWE_`type';
  };
est2one wageproc_t;
est2one wageproc_b;
mat wageproc_dprbt_tbl = wageproc_t_tbl \ wageproc_b_tbl;
mat drop wageproc_t_tbl wageproc_b_tbl;
est2tex wageproc_dprbt, ready dropall path(tex/v6fs/pt$par-af$aff-$waglvl-cf) fancy mark(starse) levels(90 95 99) replace;

}; /* end of `usemissg' loop */

log close;
cd "$root";
